<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Woo_Extra_Flat_Rate
 * @subpackage Woo_Extra_Flat_Rate/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woo_Extra_Flat_Rate
 * @subpackage Woo_Extra_Flat_Rate/admin
 * @author     Multidots <wordpress@multidots.com>
 */
class Woo_Extra_Flat_Rate_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Woo_Extra_Flat_Rate_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Woo_Extra_Flat_Rate_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        // wp_enqueue_style( 'wp-color-picker' );        
        wp_enqueue_style('wp-pointer');
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/woo-extra-flat-rate-admin.css', array('wp-jquery-ui-dialog'), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        wp_enqueue_style('wp-jquery-ui-dialog');
        wp_enqueue_script('wp-color-picker');
        wp_enqueue_script('wp-pointer');
        wp_enqueue_script('jquery-ui-datepicker');
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/woo-extra-flat-rate-admin.js', array('jquery', 'jquery-ui-dialog'), $this->version, false);
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/datepicker.js', array('jquery', 'jquery-ui-datepicker'), $this->version, false);
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/colorpicker.js', array('jquery', 'wp-color-picker'), $this->version, false);
    }

    /**
     * Add Extra Setting tab
     *
     * @since    1.0.0
     */
    public function woocommerce_inactive_notice_extra_flat_rate() {

        if (current_user_can('activate_plugins')) :
            if (!Woo_Extra_Flat_Rate::is_woocommerce_active()) :
                ?>
                <div id="message" class="error">
                    <p><?php printf(esc_html__('%1$sAdvanced Flat Rate Shipping Method For WooCommerce is inactive.%2$s The %3$sWooCommerce plugin%4$s must be active for WooCommerce Extra Flat Rate to work. Please %5$sinstall & activate WooCommerce &raquo;%6$s', 'advance-flat-rate-shipping-method-for-woocommerce'), '<strong>', '</strong>', '<a href="http://wordpress.org/extend/plugins/woocommerce/">', '</a>', '<a href="' . esc_url(admin_url('plugins.php')) . '">', '</a>'); ?>
                    </p>
                </div>
            <?php endif; ?>
            <?php
        endif;
    }

    /**
     * Register Extra shipping method tab in shipping section 
     *
     */
    public function extra_shipping_method_load_1() {

        require_once 'partials/woo-lite-extra-shipping-method-url.php';
        require_once 'partials/class-wc-lite-extra-shipping-method.php';
        require_once 'partials/woo-lite-extra-flat-rate-shipping-method.php';
        Lite_Extra_Shipping_Method::setup_own();
    }

    public function extra_flat_rate_add_body_class($classes) {
        $is_extra_method_section = !empty($_GET['section']) ? $_GET['section'] : '';
        if ($is_extra_method_section == 'wc_lite_extra_shipping_method') {
            $classes = $is_extra_method_section;
            return $classes;
        }
    }

    /**
     * Remove dotstore menu 
     * 
     *
     */
    public function remove_custom_dots_store_from_admin_menu() {
        //remove_menu_page( 'dots_store' ); 
    }

    public function extra_flat_rate_admin_init_own() {
        require_once 'partials/woo-extra-flat-rate-admin-display.php';
        $admin = new WC_Settings_Extra_Shipping_Methods();
    }

    public function welcome_screen_do_activation_redirect() {
        // Bail if no activation redirect
        if (!get_transient('_woo_extra_flat_rate_welcome_screen')) {
            return;
        }

        // Delete the redirect transient
        delete_transient('_woo_extra_flat_rate_welcome_screen');

        // Bail if activating from network, or bulk
        if (is_network_admin() || isset($_GET['activate-multi'])) {
            return;
        }

        // Redirect to bbPress about page
        wp_safe_redirect(add_query_arg(array('page' => 'wc_extra_flate_rate_plugin&tab=wc_lite_extra_shipping_get_started_method'), admin_url('admin.php')));
    }

    // custom menu for dots store menu

    public function dot_store_menu_extra_flate_rate() {
        global $GLOBALS;
        if (empty($GLOBALS['admin_page_hooks']['dots_store'])) {
            add_menu_page(
                    'DotStore Plugins', 'DotStore Plugins', 'NULL', 'dots_store', array($this, 'dot_store_menu_extra_flate_shipping_method_page'), plugin_dir_url(__FILE__) . 'images/menu-icon.png', 25
            );
        }
    }

    // custom submenu for extra flate rate shipping 

    public function add_new_menu_items_extra_flate_rate_shipping() {
        add_submenu_page("dots_store", "Advanced Flat Rate Shipping Method", "Advanced Flat Rate Shipping Method", "manage_options", "wc_extra_flate_rate_plugin", 'custom_zipcode_add_new_form_function_extra', "", 99);

        function custom_zipcode_add_new_form_function_extra() {
            $url = site_url('wp-admin/admin.php?page=wc-settings&tab=shipping&section=wc_lite_extra_shipping_method');
            $active_tab = "wc_lite_extra_shipping_method";
            if (!empty($_GET["tab"])) {

                if ($_GET["tab"] == "wc_lite_extra_shipping_method") {
                    ?>
                    <script>location.href = '<?php echo $url; ?>';</script>
                    <?php
                }
                if ($_GET["tab"] == "wc_lite_extra_shipping_premium_method") {
                    premium_dotstore_extra_flate_rate();
                }
                if ($_GET['tab'] == 'wc_lite_extra_shipping_get_started_method') {
                    get_started_dots_extra_flate_rate_plugin_settings();
                }
                if ($_GET['tab'] == 'wc_lite_extra_shipping_dotstore_contact_support_method') {
                    contact_supports_dots_extra_flate_rate_plugin_settings();
                }
                if ($_GET['tab'] == 'dotstore_introduction_extra_flate_rate_shipping') {
                    introduction_flate_rate_plugin_settings();
                }
            } else {
                ?>
                <script>location.href = '<?php echo $url; ?>';</script>
            <?php }
            ?>


            <?php
        }

    }

    //function for active menu script 

    public function woo_extra_flate_rate_active_menu() {
        $screen = get_current_screen();

        if ($screen->id == 'woocommerce_page_wc-settings') {
            $pagescrenn = $_GET['page'];
            $tabscrenn = $_GET['tab'];
            if ($pagescrenn == 'wc-settings' && $tabscrenn == 'shipping') {
                ?>
                <script type="text/javascript">
                    jQuery(document).ready(function($) {
                        $('#toplevel_page_woocommerce').removeClass('wp-menu-open wp-has-current-submenu').addClass('wp-not-current-submenu');
                        $('#toplevel_page_woocommerce > ul li a').removeClass('current');
                        $('#toplevel_page_woocommerce > ul li').removeClass('current');
                        $('#toplevel_page_dots_store').addClass('wp-has-current-submenu').removeClass('wp-not-current-submenu');
                        $('#toplevel_page_dots_store a.toplevel_page_dots_store').addClass('wp-has-current-submenu').removeClass('wp-not-current-submenu');
                        $('a[href="admin.php?page=wc_extra_flate_rate_plugin"]').parent().addClass('current');
                        $('a[href="admin.php?page=wc_extra_flate_rate_plugin"]').addClass('current');
                    });
                </script>
                <?php
            }

            // highlighed menu 

            if ($pagescrenn == 'wc-settings' && $tabscrenn == 'shipping') {
                ?>
                <script type="text/javascript">
                    jQuery(document).ready(function($) {
                        $('#toplevel_page_woocommerce').removeClass('wp-menu-open wp-has-current-submenu').addClass('wp-not-current-submenu');
                        $('#toplevel_page_woocommerce > ul li a').removeClass('current');
                        $('#toplevel_page_woocommerce > ul li').removeClass('current');
                        $('#toplevel_page_dots_store').addClass('wp-has-current-submenu').removeClass('wp-not-current-submenu');
                        $('#toplevel_page_dots_store a.toplevel_page_dots_store').addClass('wp-has-current-submenu').removeClass('wp-not-current-submenu');
                        $('a[href="admin.php?page=wc_extra_flate_rate_plugin"]').parent().addClass('current');
                        $('a[href="admin.php?page=wc_extra_flate_rate_plugin"]').addClass('current');
                    });
                </script>
                <?php
            }
        }
    }

    // Default dots store page 
    public function dot_store_menu_extra_flate_shipping_method_page() {
        ?>
        <!DOCTYPE html>
        <html>
            <head>
                <meta charset="UTF-8" />
                <meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1, maximum-scale=1">
                <title>header-1</title>
                <title>flate-rate</title>
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.6.3/css/font-awesome.min.css">
                <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i" rel="stylesheet">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/webkit.css'); ?>">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/style.css'); ?>">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/media.css'); ?>">
            </head>
            <body>
                <div id="main">
                    <div class="all-pad"> 
                        <header>
                            <div class="logo-main">
                                <img  src="<?php echo site_url(); ?>/wp-content/plugins/woocommerce-order-delivery-date/admin/images/Advance_Flat_Rate_Shipping_Method_For_WooCommerce_Paid.png">
                            </div>
                            <div class="header-right">
                                <div class="logo-detail">
                                    <strong>WooCommerce Extra Flate rate shipping </strong>
                                    <span>Version <?php echo $this->version; ?> </span>
                                </div>
                                <div class="update-blog">
                                    <a href="#">Update to<strong>PRO</strong></a>
                                </div>
                            </div>
                        </header>
                        <div class="menu-main">
                            <nav>
                                <ul>
                                    <li class="home"><a href="#"><i class="fa fa-home" aria-hidden="true"></i></a></li>
                                    <li>
                                        <a href="#">item 1</a>
                                        <ul class="sub-menu">
                                            <li><a href="#">multidots 1</a></li>
                                            <li><a href="#">multidots 2</a></li>
                                            <li><a href="#">multidots 3</a></li>
                                            <li><a href="#">multidots 4</a></li>
                                            <li><a href="#">multidots 5</a></li>
                                        </ul>
                                    </li>
                                    <li>
                                        <a href="#">item 2</a>
                                        <ul class="sub-menu">
                                            <li><a href="#">multidots 1</a></li>
                                            <li><a href="#">multidots 2</a></li>
                                            <li><a href="#">multidots 3</a></li>
                                            <li><a href="#">multidots 4</a></li>
                                            <li><a href="#">multidots 5</a></li>
                                        </ul>
                                    </li>
                                    <li>
                                        <a href="#">item 3</a>
                                        <ul class="sub-menu">
                                            <li><a href="#">multidots 1</a></li>
                                            <li><a href="#">multidots 2</a></li>
                                            <li><a href="#">multidots 3</a></li>
                                            <li><a href="#">multidots 4</a></li>
                                            <li><a href="#">multidots 5</a></li>
                                        </ul>
                                    </li>
                                    <li>
                                        <a class="active" href="#">item 4</a>
                                        <ul class="sub-menu">
                                            <li><a href="#">multidots 1</a></li>
                                            <li><a href="#">multidots 2</a></li>
                                            <li><a href="#">multidots 3</a></li>
                                            <li><a href="#">multidots 4</a></li>
                                            <li><a href="#">multidots 5</a></li>
                                        </ul>
                                    </li>
                                    <li>
                                        <a href="#">item 5</a>
                                        <ul class="sub-menu">
                                            <li><a href="#">multidots 1</a></li>
                                            <li><a href="#">multidots 2</a></li>
                                            <li><a href="#">multidots 3</a></li>
                                            <li><a href="#">multidots 4</a></li>
                                            <li><a href="#">multidots 5</a></li>
                                        </ul>
                                    </li>
                                </ul>
                            </nav>
                        </div>

                    </div>
                </div>
            </body>
        </html>					

        <?php
    }

    public function welcome_screen_pages() {
        add_dashboard_page('Welcome To WooCommerce Extra Flat Rate', 'Welcome To WooCommerce Extra Flat Rate', 'read', 'woo-extra-flat-about', array($this, 'welcome_screen_content'));
    }

    public function welcome_screen_content() {
        $current_user = wp_get_current_user();
        ?>

        <div class="wrap about-wrap">
            <h1 style="font-size: 2.1em;"><?php printf(__('Welcome to WooCommerce Extra Flat Rate', 'woo-extra-flat-rate')); ?></h1>

            <div class="about-text woocommerce-about-text">
                <?php
                $message = '';
                printf(__('%s WooCommerce Extra Flat Rate Shipping plugin is for add new flat rate option in your WooCommerce site.', 'woo-extra-flat-rate'), $message, $this->version);
                ?>
                <img class="version_logo_img" src="<?php echo plugin_dir_url(__FILE__) . 'images/woo-extra-flat-rate.png'; ?>">
            </div>

            <?php
            $setting_tabs_wc = apply_filters('woo_checkout_fields_setting_tab', array("about" => "Overview", "other_plugins" => "Checkout our other plugins", "Premium_feature" => "Premium Feature"));
            $current_tab_wc = (isset($_GET['tab'])) ? $_GET['tab'] : 'general';
            $aboutpage = isset($_GET['page'])
            ?>
            <h2 id="woo-extra-cost-tab-wrapper" class="nav-tab-wrapper">
                <?php
                foreach ($setting_tabs_wc as $name => $label)
                    echo '<a  href="' . home_url('wp-admin/index.php?page=woo-extra-flat-about&tab=' . $name) . '" class="nav-tab ' . ( $current_tab_wc == $name ? 'nav-tab-active' : '' ) . '">' . $label . '</a>';
                ?>
            </h2>
            <?php
            foreach ($setting_tabs_wc as $setting_tabkey_wc => $setting_tabvalue) {
                switch ($setting_tabkey_wc) {
                    case $current_tab_wc:
                        do_action('woocommerce_extra_flate_rate_' . $current_tab_wc);
                        break;
                }
            }
            ?>
            <hr />
            <div class="return-to-dashboard">
                <a href="<?php echo home_url('/wp-admin/admin.php?page=wc-settings&tab=shipping_methods'); ?>"><?php _e('Go to WooCommerce Extra Flat Rate Settings', 'woo-extra-flat-rate'); ?></a>
            </div>
        </div>

        <?php
        if (!get_option('wcef_plugin_notice_shown')) {
            echo '<div id="wcef_dialog" title="Basic dialog"><p> Subscribe for latest plugin update and get notified when we update our plugin and launch new products for free! </p> <p><input type="text" id="txt_user_sub_wcef" class="regular-text" name="txt_user_sub" value="' . $current_user->user_email . '"></p></div>';
            ?>

            <script type="text/javascript">

                jQuery(document).ready(function() {
                    jQuery("#wcef_dialog").dialog({
                        modal: true, title: 'Subscribe Now', zIndex: 10000, autoOpen: true,
                        width: '450', resizable: false,
                        position: {my: "center", at: "center", of: window},
                        buttons: {
                            Yes: function() {
                                // $(obj).removeAttr('onclick');
                                // $(obj).parents('.Parent').remove();
                                var email_id = jQuery('#txt_user_sub_wcef').val();

                                var data = {
                                    'action': 'add_plugin_user_wcef',
                                    'email_id': email_id
                                };

                                // since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
                                jQuery.post(ajaxurl, data, function(response) {
                                    jQuery('#wcef_dialog').html('<h2>You have been successfully subscribed');
                                    jQuery(".ui-dialog-buttonpane").remove();
                                });


                                //jQuery(this).dialog("close");
                            },
                            No: function() {

                                var email_id = jQuery('#txt_user_sub_wcef').val();

                                var data = {
                                    'action': 'hide_subscribe',
                                    'email_id': email_id
                                };

                                // since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
                                jQuery.post(ajaxurl, data, function(response) {

                                });

                                jQuery(this).dialog("close");

                            }
                        },
                        close: function(event, ui) {
                            jQuery(this).remove();
                        }
                    });
                });
            </script>
        <?php } ?>

        <?php
    }

    /**
     * Extra flate rate overview welcome about us tab content function
     *
     */
    public function woocommerce_extra_flate_rate_about() {
        $current_user = wp_get_current_user();
        ?>
        <div class="changelog">
            </br>
            <style type="text/css">
                p.extra_flate_rate_overview {max-width: 100% !important;margin-left: auto;margin-right: auto;font-size: 15px;line-height: 1.5;}.extra_flate_rate_content_ul ul li {margin-left: 3%;list-style: initial;line-height: 23px;}
            </style>  
            <div class="changelog about-integrations">
                <div class="wc-feature feature-section col three-col">
                    <div>
                        <p class="extra_flate_rate_overview"><?php _e('WooCommerce Extra Flat Rate plugin provides you an interface in WooCommerce setting section from admin side. So admin can add Multiple Shipping option(Extra Flat Rate Shipping) or remove any existing shipping from the backend. Admin set options will be displayed from the front side. So the user can choose shipping method based on that.', 'woo-checkout-fields'); ?></p>

                        <p class="extra_flate_rate_overview"><?php _e('This plugin is for those users who wants to use Multiple shipping on the website. By using this plugin, You can add multiple shipping in your wooCommerce website as well as you can add/remove it as per your requirement.', 'woo-extra-flate-rate'); ?></p> 
                        <p class="extra_flate_rate_overview"><strong>Please note:	</strong><?php _e('This plugin is only compatible for WooCommerce version (2.4.0 and more)', 'woo-extra-flate-rate'); ?></p>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    public function woocommerce_extra_flate_rate_Premium_feature() {
        ?>

        <div class="changelog">
            </br>
            <style type="text/css">
                p.extra_flate_rate_overview {max-width: 100% !important;margin-left: auto;margin-right: auto;font-size: 15px;line-height: 1.5;}.extra_flate_rate_content_ul ul li {margin-left: 3%;list-style: initial;line-height: 23px;}
            </style>  
            <div class="changelog about-integrations">
                <div class="wc-feature feature-section col three-col">
                    <div>
                        <p class="extra_flate_rate_overview"><strong>Advanced Flat Rate Shipping Method For WooCommerce Pro version: </strong></p>  
                        <p class="extra_flate_rate_overview">Need even more? upgrade to <a href="http://codecanyon.net/item/advance-flat-rate-shipping-method-for-woocommerce/15831725" rel="nofollow">Advanced Flat Rate Shipping Method For WooCommerce</a> and get all the features available in Advanced Flat Rate Shipping method for woo-commerce.</p>
                        <p class="extra_flate_rate_overview"><strong>Pro Version Features: </strong></p>
                        <p class="extra_flate_rate_overview"><strong>There are 13 types of options which allow you to add flat rate shipping method as below:</strong></p>

                        <p class="extra_flate_rate_overview"><strong>1. Location Base Shipping Method Rule</strong></p>

                        <div class="extra_flate_rate_content_ul">
                            <ul>
                                <li>Flat Rate Shipping Method For Countries OR <a target="_blank" href="http://www.multidots.com/adding-new-custom-flat-rates-with-zones-in-woocommerce-2-6/">Specific Zone</a>.</li>
                                <li>You can create custom shipping zone as per your business need (like by multiple countries, states and zip code / postcode) and you can apply multiple shipping methods on the different custom zone.</li>

                            </ul>
                        </div>

                        <p class="extra_flate_rate_overview"><strong>2. Product Base Shipping Method Rule</strong></p>

                        <div class="extra_flate_rate_content_ul">
                            <ul>
                                <li>Flat Rate Shipping Method For Specific Products.</li>
                                <li>Flat Rate Shipping Method For Specific Category.</li>
                                <li>Flat Rate Shipping Method For Specific Tag.</li>
                                <li>Flat Rate Shipping Method For Specific Product SKU.</li>
                            </ul>
                        </div>
                        <p class="extra_flate_rate_overview"><strong>3. User Base Shipping method Rule</strong></p>
                        <div class="extra_flate_rate_content_ul">
                            <ul>
                                <li>Flat Rate Shipping Method For Specific User.</li>
                                <li>Flat Rate Shipping Method For Specific User Role.</li>

                            </ul>
                        </div>
                        <p class="extra_flate_rate_overview"><strong>4. Coupon, Quantity, Order Amount Based Shipping Method Rule</strong></p>
                        <div class="extra_flate_rate_content_ul">
                            <ul>
                                <li>Flat Rate Shipping Method on particular Coupons.</li>
                                <li>Flat Rate Shipping Method on particular min/max Order amount.</li>
                                <li>Flat Rate Shipping Method on particular min/max Weight.</li>
                                <li>Flat Rate Shipping Method on particular Quantity.</li>
                                <li>Flat Rate Shipping Method on particular Shipping Class.</li>
                            </ul>
                        </div>
                        <p class="extra_flate_rate_overview"><strong>5. Shipping Class Base Shipping Method Rule</strong></p>
                    </div>
                </div>
            </div>
        </div>

        <?php
    }

    public function woocommerce_extra_flate_rate_other_plugins() {
        global $wpdb;
        $url = 'http://www.multidots.com/store/wp-content/themes/business-hub-child/API/checkout_other_plugin.php';
        $response = wp_remote_post($url, array('method' => 'POST',
            'timeout' => 45,
            'redirection' => 5,
            'httpversion' => '1.0',
            'blocking' => true,
            'headers' => array(),
            'body' => array('plugin' => 'advance-flat-rate-shipping-method-for-woocommerce'),
            'cookies' => array()));

        $response_new = array();
        $response_new = json_decode($response['body']);
        $get_other_plugin = maybe_unserialize($response_new);

        $paid_arr = array();
        ?>

        <div class="plug-containter">
            <div class="paid_plugin">
                <h3>Paid Plugins</h3>
                <?php
                foreach ($get_other_plugin as $key => $val) {
                    if ($val['plugindesc'] == 'paid') {
                        ?>


                        <div class="contain-section">
                            <div class="contain-img"><img src="<?php echo $val['pluginimage']; ?>"></div>
                            <div class="contain-title"><a target="_blank" href="<?php echo $val['pluginurl']; ?>"><?php echo $key; ?></a></div>
                        </div>	


                        <?php
                    } else {

                        $paid_arry[$key]['plugindesc'] = $val['plugindesc'];
                        $paid_arry[$key]['pluginimage'] = $val['pluginimage'];
                        $paid_arry[$key]['pluginurl'] = $val['pluginurl'];
                        $paid_arry[$key]['pluginname'] = $val['pluginname'];
                        ?>


                    <?php
                    }
                }
                ?>
            </div>
        <?php if (isset($paid_arry) && !empty($paid_arry)) { ?>
                <div class="free_plugin">
                    <h3>Free Plugins</h3>
            <?php foreach ($paid_arry as $key => $val) { ?>  	
                        <div class="contain-section">
                            <div class="contain-img"><img src="<?php echo $val['pluginimage']; ?>"></div>
                            <div class="contain-title"><a target="_blank" href="<?php echo $val['pluginurl']; ?>"><?php echo $key; ?></a></div>
                        </div>
                    <?php
                    }
                }
                ?>
            </div>

        </div>

        <?php
    }

    /**
     * Function For display admin side notice 
     *
     * 
     */
    public function custom_woo_extra_flate_rate_pointers_footer() {

        $admin_pointers = custom_woo_extra_flate_rate_admin_pointers();
        ?>
        <script type="text/javascript">
            /* <![CDATA[ */
            (function($) {
        <?php
        foreach ($admin_pointers as $pointer => $array) {
            if ($array['active']) {
                ?>
                        $('<?php echo $array['anchor_id']; ?>').pointer({
                            content: '<?php echo $array['content']; ?>',
                            position: {
                                edge: '<?php echo $array['edge']; ?>',
                                align: '<?php echo $array['align']; ?>'
                            },
                            close: function() {
                                $.post(ajaxurl, {
                                    pointer: '<?php echo $pointer; ?>',
                                    action: 'dismiss-wp-pointer'
                                });
                            }
                        }).pointer('open');
                <?php
            }
        }
        ?>
            })(jQuery);
            /* ]]> */
        </script>
        <?php
    }

    public function set_display_modefunction() {
        $mode = $_POST['radioval'];
        update_option('md_woocommerce_shipping_method_format', $mode);

        die(0);
    }

    function welcome_screen_remove_menus() {
        remove_submenu_page('index.php', 'woo-extra-flat-about');
    }

    public function admin_notices_extra_flat_rate() {
        ?>
        <div class="notice error woo-extra-flat-rate-notice is-dismissible" >
            <div><p><?php _e('You are currently using the free version of WooCommerce Flat Rate Plugin. To enjoy extra features, buy the Pro version <a href="https://store.multidots.com/advanced-flat-rate-shipping-method-for-woocommerce" target="_blank">Advanced Flat Rate Shipping Method</a>', 'my-text-domain'); ?></p></div>
        </div>
        <?php
    }

    function my_dismiss_flatrate_notice() {

        update_option('woo-extra-flat-rate-notice-dismissed', '1');
    }

    public function wp_add_plugin_userfn_wcef() {

        $email_id = $_POST['email_id'];
        $log_url = $_SERVER['HTTP_HOST'];
        $cur_date = date('Y-m-d');
        $url = 'http://www.multidots.com/store/wp-content/themes/business-hub-child/API/wp-add-plugin-users.php';
        $response = wp_remote_post($url, array('method' => 'POST',
            'timeout' => 45,
            'redirection' => 5,
            'httpversion' => '1.0',
            'blocking' => true,
            'headers' => array(),
            'body' => array('user' => array('plugin_id' => '1', 'user_email' => $email_id, 'plugin_site' => $log_url, 'status' => 1, 'activation_date' => $cur_date)),
            'cookies' => array()));

        update_option('wcef_plugin_notice_shown', 'true');
    }

    public function hide_subscribe_own() {
        $email_id = $_POST['email_id'];

        update_option('wcef_plugin_notice_shown', 'true');
    }

    public function woocommerce_get_sections_shipping_custom_lite($sections) {
        global $woocommerce;


        if (!in_array('advance-extra-flat-rate/advance-flat-rate-shipping-method-for-woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) && !is_plugin_active_for_network('advance-extra-flat-rate/advance-flat-rate-shipping-method-for-woocommerce.php.php')) {


            if (defined('WOOCOMMERCE_VERSION') && version_compare(WOOCOMMERCE_VERSION, '2.6', '>=')) {

                $sections = array(
                    '' => __('Shipping Zones', 'woocommerce'),
                    'options' => __('Shipping Options', 'woocommerce'),
                    'classes' => __('Shipping Classes', 'woocommerce'),
                        //'wc_Lite_Extra_Shipping_Method' => __('Advanced Flat Rate Shipping Method', 'woocommerce'),
                );
                return $sections;
            } else {
                return $sections;
            }
        } else {

            if (defined('WOOCOMMERCE_VERSION') && version_compare(WOOCOMMERCE_VERSION, '2.6', '>=')) {
                $sections = array(
                    '' => __('Shipping Zones', 'woocommerce'),
                    'options' => __('Shipping Options', 'woocommerce'),
                    'classes' => __('Shipping Classes', 'woocommerce'),
                        //'wc_Lite_Extra_Shipping_Method' => __('Advanced Flat Rate Shipping Method', 'woocommerce'),
                        //'wc_Extra_Shipping_Method' => __('Advance Flat Rate Shipping', 'woocommerce'),
                );

                return $sections;
            } else {

                return $sections;
            }
        }
    }

}

function custom_woo_extra_flate_rate_admin_pointers() {

    $dismissed = explode(',', (string) get_user_meta(get_current_user_id(), 'dismissed_wp_pointers', true));
    $version = '1_0'; // replace all periods in 1.0 with an underscore
    $prefix = 'custom_woocommerce_extra_flate_rate_admin_pointers' . $version . '_';

    $new_pointer_content = '<h3>' . __('WooCommerce Extra Flat Rate') . '</h3>';
    $new_pointer_content .= '<p>' . __('WooCommerce Extra Flat Rate Shipping plugin is for add new flat rate option in your WooCommerce site.') . '</p>';

    return array(
        $prefix . 'custom_woocommerce_extra_flate_rate_admin_pointers' => array(
            'content' => $new_pointer_content,
            'anchor_id' => '#toplevel_page_woocommerce',
            'edge' => 'left',
            'align' => 'left',
            'active' => (!in_array($prefix . 'custom_woocommerce_extra_flate_rate_admin_pointers', $dismissed) )
        )
    );
}

// premium tab function 
function premium_dotstore_extra_flate_rate() {
    all_admin_menu_side_header_part();
    ?>
    <style type="text/css">
        td.fr-2 {text-align: center;}
        .flat-table {width: 69%;display: block;box-sizing: border-box;margin: 0 auto; float: none !important;}
        .flat-table h2 {font-size: 19px;font-weight: bold;color: #333;border: 1px solid #ddd;padding: 16px;border-bottom: 0;background: #e9e9e9;text-align: center !important;}

    </style>

    <div class="flat-table res-cl">
        <h2>Free vs Premium </h2>
        <table class="table-outer free_and_paid_table">
            <tbody>
                <tr>
                    <td> 
                        <div class="premium-table-fees">
                            <img  style="border-bottom: 1px solid #eee;"src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/price_table.png'); ?>">
                            <div class="image_paid_download_button">
                                <a target="_blank" href="https://wordpress.org/plugins/woo-extra-flat-rate/"><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/free_download.png'); ?>"></a>
                                <a  target="_blank" href="https://store.multidots.com/advanced-flat-rate-shipping-method-for-woocommerce/"><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/paid_download.png'); ?>"></a>
                            </div>
                        </div>	
                    </td>
                </tr>
            </tbody>
        </table>

    </div>

    <div class="flat-table res-cl">
        <h2>Premium Version Features</h2>
        <table class="table-outer">
            <tbody>
                <tr >
                    <td class="fr-2">
                        <div class="premium_one">
                            <img src="https://store.multidots.com/wp-content/uploads/2016/10/flat-rate-quick-info.jpg">
                        </div>
                        <div class="premium_one">
                            <a href="https://wordpress.org/plugins/woo-extra-flat-rate/" rel="nofollow"><img src="https://store.multidots.com/wp-content/uploads/2016/10/1000.jpg"></a>
                        </div>
                        <div class="premium_two">
                            <a href="https://www.youtube.com/watch?v=HqlBb7OoyFo" rel="nofollow"><img  style="width: 50% !important;" src="https://store.multidots.com/wp-content/uploads/2016/10/yellow-button.jpg"></a> <a href="http://extraflatratedemo.projectsmd.in/" rel="nofollow"><img style="width: 50% !important;" src="https://store.multidots.com/wp-content/uploads/2016/10/blue-button.jpg"></a>
                        </div>
                        <div class="premium_one">
                            <img src="https://store.multidots.com/wp-content/uploads/2016/10/mb.jpg">
                        </div>
                        <div class="premium_one">
                            <img src="https://store.multidots.com/wp-content/uploads/2016/10/real.jpg">
                        </div>
                        <div class="premium_one">
                            <img src="https://store.multidots.com/wp-content/uploads/2016/10/question.jpg">
                        </div>
                        <div class="premium_one">
                            <img src="https://store.multidots.com/wp-content/uploads/2016/10/customer.jpg">
                        </div>
                        <div class="premium_one">	
                            <a href="https://codecanyon.net/item/advance-flat-rate-shipping-method-for-woocommerce/reviews/15831725"><img src="https://store.multidots.com/wp-content/uploads/2016/10/mj.jpg"></a>
                            </br></br>
                            <p><strong style="font-size: 21px;font-weight: bold;">Do you need all of above features?</strong></p>
                            </p><a  target = "_blank" href="https://store.multidots.com/go/Flatrate-NEWUI-header-UPGRADETO-PRO" ><img style="width: 224px !important;" width="232px" src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/upgrade_new.png'); ?>"></a></p>
                        </div>
                    </td>
                </tr>
            </tbody>
        </table>
    </div>
    <?php //dotstore_left_side_menu();    ?>
    </div>
    </div>
    </body>
    </html>
    <?php
}

// function for get started page 

function get_started_dots_extra_flate_rate_plugin_settings() {
    all_admin_menu_side_header_part();
    ?>
    <div class="flat-table res-cl">
        <h2>Thanks For Installing Advanced Flat Rate Shipping Method</h2>
        <table class="table-outer">
            <tbody>
                <tr>
                    <td class="fr-2">
                        <p class="block gettingstarted"><strong>Getting Started </strong></p>
                        <p class="block textgetting">
                            Create multiple shipping rules as per your needs from Add New Shipping Method
                        </p>
                        <p class="block textgetting">
                            <strong>Step 1 :</strong> Basic configuration: " Enter Shipping Method Name  and  Amount to Charge."
                            <span class="gettingstarted">
                                <img style="border-bottom: 2px solid #E9E9E9;margin-top: 3%;"src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/step1.png'); ?>"></span>
                        </p>
                        <p class="block gettingstarted textgetting">
                            <strong>Step 2 :</strong> You can create shipping method for  Specific Product/ Category / Countries.Eg. you want to create product base shipping method then select a specific product and save changes
                            <span class="gettingstarted">
                                <img style="border: 2px solid #e9e9e9;margin-top: 3%;" src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/step2.png'); ?>"></span>
                        </p>

                        <p class="block gettingstarted textgetting">
                            <strong>Step 3 :</strong> Now, you can see All shipping method list here.
                            <span class="gettingstarted">
                                <img style="border: 2px solid #e9e9e9;margin-top: 3%;" src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/screenshot_3.png'); ?>"></span>
                        </p>
                        <p class="block gettingstarted textgetting">
                            <strong>Please note:</strong> This plugin is only compatible for WooCommerce version (2.4.0 and more)
                        </p>

                    </td>
                </tr>
            </tbody>
        </table>
    </div>

    <?php dotstore_left_side_menu(); ?>
    </div>
    </div>
    </body>
    </html>
    <?php
}

function contact_supports_dots_extra_flate_rate_plugin_settings() {
    all_admin_menu_side_header_part();
    ?>
    <form id="cw_plugin_form_id"  > 
        <div class="under-table third-tab">
            <div class="set">
                <h2><?php echo __("Contact Supports", AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></h2>
            </div>
            <table class="table-outer">
                <tbody>  
                    <tr>
                <iframe src="https://store.multidots.com/dotstore-support/#/home" width="100%" height="500px"></iframe>
                </tr>
                </tbody>
            </table>
        </div>
    </form>
    </div>
    <?php dotstore_left_side_menu(); ?>
    </div>
    </body>
    </html>
    <?php
}

function introduction_flate_rate_plugin_settings() {

    $plugin_name = "Advanced Flat Rate Shipping Method";
    $plugin_version = "2.4";

    all_admin_menu_side_header_part();
    ?>
    <form id="cw_plugin_form_id"  > 
        <style type="text/css">.dotstore_plugin_supports_feature {margin-top: -19px !important;}</style>
        <div class="under-table third-tab">
            <div class="set">
                <h2><?php echo __("Introduction", AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></h2>
            </div>
            <table class="table-outer">
                <tbody>
                    <tr>
                        <td class="fr-1">Product Type</td>
                        <td class="fr-2">WordPress Plugin</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Product Name</td>
                        <td class="fr-2"><?php echo $plugin_name; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">Installed Version</td>
                        <td class="fr-2"><?php echo $plugin_version; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">License & Terms of use</td>
                        <td class="fr-2"> <a href="#">Click here</a> to view license and terms of use.</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Help & Support</td>
                        <td class="fr-2"><li><a href="<?php echo site_url('/wp-admin/admin.php?page=wc_extra_flate_rate_plugin&tab=wc_lite_extra_shipping_get_started_method'); ?>" target="_blank"> Quick Start Guide</a></li><br><li><a href="https://store.multidots.com/docs/plugin/advanced-flat-rate-shipping-method-for-woocommerce/" target="_blank">Documentation</a> </li><br><li><a href="https://store.multidots.com/dotstore-support-panel/" target="_blank"> Support Fourm</a></li></td>
                </tr>
                <tr>
                    <td class="fr-1">Localization</td>
                    <td class="fr-2">English ,Spanish</td>
                </tr>
                <tr>
                    <th></th>
                </tr>
                </tbody>
            </table>

        </div>
    </form>
    </div>
    <?php dotstore_left_side_menu(); ?>
    </div>
    </body>
    </html>
    <?php
}

function all_admin_menu_side_header_part() {
    $plugin_name = "Advanced Flat Rate Shipping Method";
    $plugin_version = "2.4";
    ?>
    <html>
        <head>
            <meta charset="UTF-8" />
            <meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1, maximum-scale=1">
            <title>header-1</title>
            <title>flate-rate</title>
            <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.6.3/css/font-awesome.min.css">
            <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i" rel="stylesheet">
            <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/webkit.css'); ?>">
            <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/style.css'); ?>">
            <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/media.css'); ?>">
        </head>

        <body>
            <div id="main">
                <div class="all-pad">
                    <header>
                        <div class="logo-main">
                            <img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/advance_flat_rate_free.png'); ?>">
                        </div>
                        <div class="header-right">
                            <div class="logo-detail">
                                <strong><?php echo $plugin_name; ?></strong>
                                <span>Free Version <?php echo "v" . $plugin_version; ?></span>
                            </div>
                            <div class="button-dots">
                                <span class="support_dotstore_image"><a href="https://store.multidots.com/go/Flatrate-NEWUI-header-UPGRADETO-PRO" target="_blank"><img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/upgrade_new.png'); ?>"> </a></span>
                                <span class="support_dotstore_image"><a  target="_blank" href="https://store.multidots.com/dotstore-support-panel/" > <img   src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/support_new.png'); ?>"></a></span>
                            </div>
                        </div>
                    </header>
                    <?php
                    $lite_flate_rate_methode = '';
                    $add_new_lite_flate_rate_methode = '';
                    $premium_tab_dotstore_extra_flate_rate = '';
                    $wc_lite_extra_shipping_get_started_method = '';
                    $wc_lite_extra_shipping_dotstore_contact_support_method = '';
                    $dotstore_introduction_extra_flate_rate_shipping = '';
                    $dotstore_setting_menu_enable = '';
                    $dotpremium_setting_menu_enable = '';

                    if ((!empty($_GET['extra_method']) && $_GET['extra_method'] != '' && !empty($_GET['section']) && $_GET['section'] == 'wc_lite_extra_shipping_method')) {
                        $add_new_lite_flate_rate_methode = "active";
                    }
                    if (( empty($_GET['extra_method']) && !empty($_GET['section']) && $_GET['section'] == 'wc_lite_extra_shipping_method')) {
                        $lite_flate_rate_methode = "active";
                    }

                    if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_premium_method') {
                        $premium_tab_dotstore_extra_flate_rate = "active";
                    }
                    if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_get_started_method') {
                        $wc_lite_extra_shipping_get_started_method = "active";
                    }
                    if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_dotstore_contact_support_method') {
                        $wc_lite_extra_shipping_dotstore_contact_support_method = "active";
                    }
                    if (!empty($_GET['tab']) && $_GET['tab'] == 'dotstore_introduction_extra_flate_rate_shipping') {
                        $dotstore_introduction_extra_flate_rate_shipping = "active";
                    }

                    $site_url = "admin.php?page=wc_extra_flate_rate_plugin&tab=";
                    ?>
                    <div class="menu-main">
                        <nav>
                            <ul>
                                <li>
                                    <a class="dotstore_plugin <?php echo $lite_flate_rate_methode; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_method'; ?>">Manage Shipping Methods </a>
                                </li>
                                <li>
                                    <a class="dotstore_plugin <?php echo $add_new_lite_flate_rate_methode; ?>" href="<?php echo esc_html(liteExtraShippingMethodUrl::create()) ?>"> Add New Shipping Method </a>
                                </li>
                                <li>
                                    <a class="dotstore_plugin <?php echo $premium_tab_dotstore_extra_flate_rate; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_premium_method'; ?>">Premium Version</a>
                                </li>
                                <li>
                                    <a class="dotstore_plugin <?php echo $wc_lite_extra_shipping_get_started_method; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_get_started_method'; ?>">About Plugin</a>
                                    <ul class="sub-menu">
                                        <li><a  class="dotstore_plugin <?php echo $wc_lite_extra_shipping_get_started_method; ?>" href="<?php echo $site_url . 'wc_lite_extra_shipping_get_started_method'; ?>">Getting Started</a></li>
                                        <li><a class="dotstore_plugin <?php echo $dotstore_introduction_extra_flate_rate_shipping; ?>" href="<?php echo $site_url . 'dotstore_introduction_extra_flate_rate_shipping'; ?>">Introduction</a></li>
                                        <li><a  target="_blank" href="https://store.multidots.com/suggest-a-feature/">Suggest A Feature</a></li>	
                                        <!--<li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');   ?>">Plugin Tour</a></li>
                                        <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');   ?>">Change Log</a></li>
                                        <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');   ?>">Documention</a></li>
                                        <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');   ?>">Upgrade To Premium</a></li>
                                        <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');   ?>">Suggested Feature</a></li>
                                        <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');    ?>">Rate This Plugin</a></li>-->
                                    </ul>

                                </li>

                                <li>
                                    <a class="dotstore_plugin <?php echo $wc_lite_extra_shipping_dotstore_contact_support_method; ?>"  href="#">Dotstore</a>
                                    <ul class="sub-menu">
                                        <li><a target="_blank" href="https://store.multidots.com/go/Flatrate-newui-woocommerce-Plugins">WooCommerce Plugins</a></li>
                                        <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-Wordpress-Plugins">Wordpress Plugins</a></li><br>
                                        <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-Wordpress-Plugins">Free Plugins</a></li>
                                        <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-theme">Free Themes</a></li>
                                        <li><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Contact Support</a></li>
                                    </ul>
                                </li>

                            </ul>

                            </li>
                            </ul>
                        </nav>
                    </div>
                    <?php
                }

// function for add left side menu bar 

                function dotstore_left_side_menu() {
                    $site_url = "admin.php?page=wc_extra_flate_rate_plugin&tab=";
                    ?>
                    <div class="dotstore_plugin_supports_feature">
                        <div class="right-sec">
                            <div class="woo-top">
                                <span>discover features</span>
                            </div>
                            <div class="discover">
                                <div class="video">
                                    <iframe width="100%" height="232" src="https://www.youtube.com/embed/HqlBb7OoyFo" frameborder="0" allowfullscreen></iframe>
                                </div>
                                <div class="video-detail">
                                    <ul>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span >Location Based Shipping Rules </span><li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span>Product Based Shipping Rules</span> <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span>User Based Shipping Rules</span> </li><li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span >Coupon, Quantity Based Shipping Rules</span></li>
                                    </ul>
                                </div>
                                <div class="view-button">
                                    <a  class="view_button_dotstore" target="_blank" href="<?php echo $site_url . 'wc_lite_extra_shipping_premium_method'; ?>" >view details</a>
                                    <a  class="live_button_dotstore" target="_blank" href="http://extraflatratedemo.projectsmd.in/">live demo</a>
                                </div>
                            </div>
                            <div class="dotstore-blog">
                                <img width="100%" src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/Discount.png'); ?>">

                            </div>
                            <div class="upgrader_pro_version_button">
                                <a href="https://store.multidots.com/go/Flatrate-NEWUI-UPGRADETO-PRO--sidebar" target="_blank"><img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/upgrade_new.png'); ?>"> </a></div>
                            <div class="dotstore-important-link">
                                <h2><span class="dotstore-important-link-title">Important link</span></h2>
                                <div class="video-detail important-link">
                                    <ul>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/docs/plugin/advanced-flat-rate-shipping-method-for-woocommerce/">Plugin documentation</a></li> 
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Support platform</a></li>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/suggest-a-feature/">Suggest A Feature</li>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a  target="_blank" href="https://store.multidots.com/advanced-flat-rate-shipping-method-for-woocommerce/">Changelog</li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                        <?php
                    }
                    