<?php

/**
 * Flat Rate Shipping Method.
 *
 */
class WC_Lite_Extra_Shipping_Method extends WC_Shipping_Method {

    const PLUGIN_PREFIX = 'extra_';

    public $plugin_id = self::PLUGIN_PREFIX;
    public $name;
    public $profile_id;
    public $weight;
    public $subtotal;
    public $subtotalWithTax;
    public $weightRate;
    public $shippingClassRates;
    public $priceClamp;
    public $_extra_stub = false;
    protected $fee_cost = '';

    /**
     * Constructor.
     */
    public function __construct($profileId = null) {

        $manager = Lite_Extra_Shipping_Method::instance();

        // Force loading profiles when called from WooCommerce 2.3.9- save handler
        // to activate process_admin_option() with appropriate hook
        if (!isset($profileId)) {
            $manager->profiles();
        }

        $this->id = $manager->find_suitable_id($profileId);
        $this->profile_id = $profileId;
        $this->method_title = __('Advanced Flat Rate Shipping Method Method', 'flat-rate-shipping-method-for-woocommerce');
        $this->method_description = __('Advanced Flat Rate Shipping Method lets you charge a fixed rate for shipping.', 'flat-rate-shipping-method-for-woocommerce');

        $this->init();
        add_action('woocommerce_settings_save_' . 'wc_Lite_Extra_Shipping_Method', 'save_extra_shipping_settings');
    }

    /**
     * Initialize flat rate shipping.
     */
    public function init() {
        // Load the settings.
        $this->init_form_fields_own();
        $this->init_settings();

        // Define user set variables
        $this->title = $this->get_option('title');
        $this->availability = $this->get_option('availability');
        $this->tax_status = $this->get_option('tax_status');
        $this->shipping_description = $this->get_option('shipping_description');
        $this->cost = $this->get_option('cost');
        $this->type = $this->get_option('type', 'class');
        $this->options = $this->get_option('options', false); // @deprecated in 2.4.0
        $this->extra_shipping_requires = $this->get_option('extra_shipping_requires');

        //Selection base shipping
        $this->countries = $this->get_option('countries');
        $this->product_base = $this->get_option('product_base');
        $this->category_base = $this->get_option('category_base');

        //Get different condition option
    }

    public function get_wp_option_name() {
        return Lite_Extra_Shipping_Method::getRuleSettingsOptionName($this->id, $this->plugin_id);
    }

    /**
     * Initialize Settings Form Fields.
     */
    public function init_form_fields_own() {
        global $wpdb;

        global $wpdb;
        $current_user = wp_get_current_user();
        $userid = $current_user->ID;

        $current_user = wp_get_current_user();
        $userid = get_current_user_id();

        /* $cost_desc = __('This amount will be added to the sub total of the order when customer selects this shipping method. You can enter direct amount or make it dynamic using parameters. Below are the parameters you can use: [qty] = number of items, [cost] = cost of items <br>[fee percent="10" min_fee="20"] = Percentage based fee. Below are some of the examples:"10.00"  - To charge flat 10.00 shipping charge"10.00 * [qty]" - To charge 10.00 per quantity in the cart. It will be 50.00 if the cart has 5 qty. "[fee percent="10" min_fee="20"]" - This means charge 10 percent sub total of order, minimum 20 charge will be applicable. ', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); */

        $cost_desc = __('This amount will be added to the sub total of the order when customer selects this shipping method.', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG);


        $this->form_fields = array(
            'enabled' => array(
                'title' => __('<span class="enable_flate_rate_classs">Enable this Method</span>', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'checkbox',
                'description' => __('Enable this shipping method  (This method will be visible to customers only if it is enabled.)', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'default' => 'yes',
                'class' => 'extra_flate_rate_enable'
            ),
            /* 'user_id_extra_flat' => array(
              'title' => __('', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
              'type' => 'hidden',
              'label' => __('', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
              'default' => $userid,
              'class'=>'extra_flat_userid lite_extra_flate_rate_user_id'
              ), */
            'title' => array(
                'title' => __('Shipping Method Name *', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) . '',
                'type' => 'text',
                'placeholder' => __('Enter shipping method name', 'placeholder', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'description' => __('This name will be visible to the customer at the time of checkout. This should convey the purpose of the charges you are applying to the order. For example "Ground Shipping",  "Express Shipping Flat Rate", "Christmas Next Day Shipping" etc', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                //'default' => sprintf($this->profile_id != 'extra_shipping' ? __('extra_shipping: %s') : '%s', $this->profile_id),
                'custom_attributes' => array(
                    'required' => true
                )
            ),
            'shipping_description' => array(
                'title' => __('Short Description about this Shipping method ', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'textarea',
                'description' => __('Enter few words about this shipping method. This will help your customers to understand the shipping charges in more detailed way. ', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'default' => '',
                'placeholder' => __('Enter method description', 'placeholder', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
            ),
            'cost' => array(
                'title' => __('Shipping Charge&nbsp;(' . get_woocommerce_currency_symbol() . ')*', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'text',
                'placeholder' => get_woocommerce_currency_symbol(),
                'description' => $cost_desc,
                'default' => '',
                'required' => true
            ),
            'countries' => array(
                'title' => __('Specific Countries', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'multiselect',
                'class' => 'wc-enhanced-select',
                'css' => 'width: 450px;',
                'default' => '',
                'description' => __('Using this feature you can apply shipping method by all Country wise.', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'options' => WC()->countries->get_shipping_countries(),
                'custom_attributes' => array(
                    'data-placeholder' => __('Select some countries', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG)
                )
            ),
            'product_base' => array(
                'title' => __('Select Specific Products', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'multiselect',
                'class' => 'wc-enhanced-select',
                'options' => $this->get_product_list_own(),
                'css' => 'width: 450px;',
                'default' => '',
                'description' => __('Use this feature when you want to make the shipping method visible only for specific products. For example, if you select "Basketball" as product, the current shipping method will only be visible if the customer has added "Basketball" product in his current cart.', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'custom_attributes' => array(
                    'data-placeholder' => __('Select some products', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG)
                )
            ),
            'category_base' => array(
                'title' => __('Select Specific Category', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'multiselect',
                'class' => 'wc-enhanced-select',
                'options' => $this->get_category_list_own(),
                'css' => 'width: 450px;',
                'default' => '',
                'description' => __('Using this feature you can restrict your shipping method to be visible only for products of specific category.  For example, you can create a new method like "Expensive Shipping $50".  This method should be visible only when the cart has any product from "Glass Products" category.', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'custom_attributes' => array(
                    'data-placeholder' => __('Select some categories', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG)
                )
            ),
            'tax_status' => array(
                'title' => __('Should the shipping amount be taxable?', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'select',
                'class' => 'wc-enhanced-select',
                'default' => 'taxable',
                'description' => __('If Tax Status is "Yes" then tax rate will apply on Shipping Cost as well. You can Manage your Tax rate by <a href="' . admin_url('admin.php?page=wc-settings&tab=tax') . '">Click here</a>', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'options' => array(
                    'taxable' => __('YES', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                    'none' => __('NO', 'Tax status', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG)
                )
            )
        );

        $shipping_classes = WC()->shipping->get_shipping_classes();

        if (!empty($shipping_classes)) {
            $this->form_fields['class_costs'] = array(
                'type' => 'title',
                'description' => sprintf(__('These costs can optionally be added based on the %sproduct shipping class%s.', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG), '<a href="' . admin_url('edit-tags.php?taxonomy=product_shipping_class&post_type=product') . '">', '</a>')
            );
            foreach ($shipping_classes as $shipping_class) {
                if (!isset($shipping_class->term_id)) {
                    continue;
                }
                $this->form_fields['class_cost_' . $shipping_class->term_id] = array(
                    'title' => sprintf(__('"%s" Shipping Class Cost', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG), esc_html($shipping_class->name)),
                    'type' => 'text',
                    'placeholder' => __('N/A', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                    'desc_tip' => true,
                    'description' => $cost_desc,
                    'default' => $this->get_option('class_cost_' . $shipping_class->slug), // Before 2.5.0, we used slug here which caused issues with long setting names
                );
            }
            $this->form_fields['no_class_cost'] = array(
                'title' => __('No Shipping Class Cost', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'text',
                'placeholder' => __('N/A', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'description' => $cost_desc,
                'default' => '',
            );
            $this->form_fields['type'] = array(
                'title' => __('Calculation Type', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                'type' => 'select',
                'class' => 'wc-enhanced-select',
                'default' => 'class',
                'options' => array(
                    'class' => __('Per Class: Charge shipping for each shipping class individually', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                    'order' => __('Per Order: Charge shipping for the most expensive shipping class', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG),
                ),
            );
        }
    }

    /**
     * Generate Checkbox HTML.
     *
     * @param  mixed $key
     * @param  mixed $data
     * @since  1.0.0
     * @return string
     */
    public function generate_checkbox_html($key, $data) {
        $field_key = $this->get_field_key($key);
        $defaults = array(
            'title' => '',
            'label' => '',
            'disabled' => false,
            'class' => '',
            'css' => '',
            'type' => 'text',
            'desc_tip' => false,
            'description' => '',
            'custom_attributes' => array(),
        );

        $data = wp_parse_args($data, $defaults);

        if (!$data['label']) {
            $data['label'] = $data['title'];
        }

        ob_start();
        ?>
        <tr valign="top">
            <th scope="row" class="titledesc">
                <label for="<?php echo esc_attr($field_key); ?>"><?php echo wp_kses_post($data['title']); ?></label>
                <?php echo $this->get_tooltip_html($data); ?>
            </th>
            <td class="forminp">
                <fieldset>
                    <legend class="screen-reader-text"><span><?php echo wp_kses_post($data['title']); ?></span></legend>
                    <label for="<?php echo esc_attr($field_key); ?>">
                        <input <?php disabled($data['disabled'], true); ?> class="<?php echo esc_attr($data['class']); ?>" type="checkbox" name="<?php echo esc_attr($field_key); ?>" id="<?php echo esc_attr($field_key); ?>" style="<?php echo esc_attr($data['css']); ?>" value="1" <?php checked($this->get_option($key), 'yes'); ?> <?php echo $this->get_custom_attribute_html($data); ?> /> <?php echo wp_kses_post($data['label']); ?></label><br/>
                    <?php echo $this->get_description_html($data); ?>
                </fieldset>
            </td>
        </tr>
        <?php
        return ob_get_clean();
    }

    /**
     * Function for select product list
     *
     */
    public function get_product_list() {

        global $wpdb, $post;

        $product_array = array();

        $get_all_products = new WP_Query(array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'posts_per_page' => -1
        ));

        if (isset($get_all_products->posts) && !empty($get_all_products->posts)) {

            foreach ($get_all_products->posts as $get_all_product) {
                $product_array[$get_all_product->ID] = $get_all_product->post_title;
            }
        }

        return apply_filters('woocommerce_extra_shipping_product_list', $product_array);
    }

    /**
     * get all shipping class name
     *
     */
    public function get_advance_flat_rate_class() {

        $shipping_classes = WC()->shipping->get_shipping_classes();
        $shipping_class_name = array();

        foreach ($shipping_classes as $shipping_classes_key) {
            $shipping_class_name[$shipping_classes_key->slug] = $shipping_classes_key->name;
        }

        array_unshift($shipping_class_name, "Select Class");

        return $shipping_class_name;
    }

    /**
     * Function for select category list
     *
     */
    public function get_category_list() {

        global $wpdb, $post;

        $taxonomy = 'product_cat';
        $post_status = 'publish';
        $orderby = 'name';
        $hierarchical = 1;      // 1 for yes, 0 for no
        $empty = 0;

        $args = array(
            'post_type' => 'product',
            'post_status' => $post_status,
            'taxonomy' => $taxonomy,
            'orderby' => $orderby,
            'hierarchical' => $hierarchical,
            'hide_empty' => $empty,
            'posts_per_page' => -1
        );

        $get_all_categories = get_categories($args);

        $category_array = array();

        if (isset($get_all_categories) && !empty($get_all_categories)) {

            foreach ($get_all_categories as $get_all_category) {
                $category_array[$get_all_category->term_id] = $get_all_category->cat_name;
            }
        }
        return apply_filters('woocommerce_extra_shipping_category_list', $category_array);
    }

    public function get_product_list_own() {

        global $wpdb, $post;
        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;

        $product_array = array();

        $get_all_products = new WP_Query(array(
            'post_type' => 'product',
            'post_status' => 'publish',
            'posts_per_page' => -1,
            'author' => $user_id
        ));

        if (isset($get_all_products->posts) && !empty($get_all_products->posts)) {

            foreach ($get_all_products->posts as $get_all_product) {
                $product_array[$get_all_product->ID] = '#' . $get_all_product->ID . ' - ' . $get_all_product->post_title;
            }
        }

        return apply_filters('woocommerce_extra_shipping_product_list', $product_array);
    }

    /**
     * Function for select category list
     *
     */
    public function get_category_list_own() {

        global $wpdb, $woocommerce, $post;
        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;

        $taxonomy = 'product_cat';
        $post_status = 'publish';
        $orderby = 'name';
        $hierarchical = 1;      // 1 for yes, 0 for no
        $empty = 0;

        $args = array(
            'post_type' => 'product',
            'post_status' => $post_status,
            'taxonomy' => $taxonomy,
            'orderby' => $orderby,
            'hierarchical' => $hierarchical,
            'hide_empty' => $empty,
            'posts_per_page' => -1,
            'author' => $user_id
        );

        $get_all_categories = get_categories($args);
        $category_array = array();
        if (!empty($get_all_categories) && $get_all_categories != '') {

            if (isset($get_all_categories) && !empty($get_all_categories)) {

                foreach ($get_all_categories as $get_all_category) {

                    $category = get_category($get_all_category->term_id);

                    if (!empty($category) && $category->parent > 0) {
                        $category_array[$get_all_category->term_id] = '#' . get_cat_name($category->parent) . '&nbsp;&#x2192;&nbsp;' . $get_all_category->cat_name;
                    } else {
                        $category_array[$get_all_category->term_id] = $get_all_category->cat_name;
                    }
                }
            }
        }



        return apply_filters('woocommerce_extra_shipping_category_list', $category_array);
    }

    /**
     * Save Extra Shipping settings
     *
     */
    public function save_extra_shipping_settings() {

        global $current_section;

        $wc_shipping = WC_Shipping::instance();

        if (!$current_section) {
            WC_Admin_Settings::save_fields($this->get_settings());
            $wc_shipping->process_admin_options();
        } else {
            foreach ($wc_shipping->load_shipping_methods() as $method_id => $method) {
                if ($current_section === sanitize_title(get_class($method))) {
                    do_action('woocommerce_update_options_' . $this->id . '_' . $method->id);
                }
            }
        }

        // Increments the transient version to invalidate cache
        WC_Cache_Helper::get_transient_version('shipping', true);
    }

    /**
     * Evaluate a cost from a sum/string.
     * @param  string $sum
     * @param  array  $args
     * @return string
     */
    protected function evaluate_cost($sum, $args = array()) {
        include_once( 'class-wc-lite-extra-flat-eval-math.php' );

        // Allow 3rd parties to process shipping cost arguments
        $args = apply_filters('woocommerce_evaluate_shipping_cost_args', $args, $sum, $this);
        $locale = localeconv();
        $decimals = array(wc_get_price_decimal_separator(), $locale['decimal_point'], $locale['mon_decimal_point']);
        $this->fee_cost = $args['cost'];

        // Expand shortcodes
        add_shortcode('fee', array($this, 'fee'));

        $sum = do_shortcode(str_replace(
                        array(
            '[qty]',
            '[cost]'
                        ), array(
            $args['qty'],
            $args['cost']
                        ), $sum
        ));

        remove_shortcode('fee', array($this, 'fee'));

        // Remove whitespace from string
        $sum = preg_replace('/\s+/', '', $sum);

        // Remove locale from string
        $sum = str_replace($decimals, '.', $sum);

        // Trim invalid start/end characters
        $sum = rtrim(ltrim($sum, "\t\n\r\0\x0B+*/"), "\t\n\r\0\x0B+-*/");

        // Do the math
        return $sum ? WC_Eval_Math_Extra::evaluate($sum) : 0;
    }

    /**
     * Work out fee (shortcode).
     * @param  array $atts
     * @return string
     */
    public function fee($atts) {
        $atts = shortcode_atts(array(
            'percent' => '',
            'min_fee' => ''
                ), $atts);

        $calculated_fee = 0;

        if ($atts['percent']) {
            $calculated_fee = $this->fee_cost * ( floatval($atts['percent']) / 100 );
        }

        if ($atts['min_fee'] && $calculated_fee < $atts['min_fee']) {
            $calculated_fee = $atts['min_fee'];
        }

        return $calculated_fee;
    }

    /**
     * Check if free shipping is available.
     *
     * @param array $package
     * @return bool
     */
    public function is_available($package) {

        if ('no' == $this->enabled) {
            return false;
        }

        // Enabled logic based on condition
        $is_available = false;
        $has_ship_based_on_countries = 'no';
        $has_ship_based_on_product = 'no';
        $has_ship_based_on_category = 'no';

        $is_passed = array();

        if (isset($this->settings['enabled']) && $this->settings['enabled'] == 'no') {
            $is_passed['enabled'] = 'no';
        } else if (isset($this->settings['enabled']) && $this->settings['enabled'] == 'yes') {
            $is_passed['enabled'] = 'yes';
        } else {
            $is_passed['enabled'] = 'yes';
        }


        //Check if is Country exist
        if ('specific' == $this->availability) {
            $ship_to_countries = $this->countries;
        } else {
            $ship_to_countries = array_keys(WC()->countries->get_shipping_countries());
        }
        $ship_to_countries = $this->countries;

        if (isset($ship_to_countries) && !empty($ship_to_countries)) {
            if (is_array($ship_to_countries) && !in_array($package['destination']['country'], $ship_to_countries)) {
                $is_passed['has_ship_based_on_countries'] = 'no';
                $has_ship_based_on_product = 'no';
            } else {
                $is_passed['has_ship_based_on_countries'] = 'yes';
                $has_ship_based_on_countries = 'yes';
            }
        }

        //Check if is product exist
        if (is_array($this->product_base) && isset($this->product_base) && isset($package['contents'])) {
            $product_base_array = $this->product_base;

            $cart_product_id_array = array();
            foreach ($package['contents'] as $package_product) {
                $cart_product_id_array[] = $package_product['product_id'];
            }

            $product_array_intersect = array();
            $product_array_intersect = array_intersect($product_base_array, $cart_product_id_array);
            $product_array_intersect_count = count($product_array_intersect);

            if (isset($product_array_intersect) && !empty($product_array_intersect) && $product_array_intersect_count >= 1) {
                $is_passed['has_ship_based_on_product'] = 'yes';
                $has_ship_based_on_product = 'yes';
            } else {
                $is_passed['has_ship_based_on_product'] = 'no';
                $has_ship_based_on_product = 'no';
            }
        }

        //Check if is category exist
        if (is_array($this->category_base) && isset($this->category_base) && isset($package['contents'])) {
            $category_base_array = $this->category_base;

            $cart_category_id_array = array();
            foreach ($package['contents'] as $package_product) {
                $wp_category_id_exist = wp_get_post_terms($package_product['product_id'], 'product_cat', array('fields' => 'ids'));
                if (isset($wp_category_id_exist) && !empty($wp_category_id_exist) && is_array($wp_category_id_exist)) {
                    $cart_category_id_array[] = $wp_category_id_exist[0];
                }
            }

            $cart_category_id_count = count($cart_category_id_array);
            if (isset($cart_category_id_array) && !empty($cart_category_id_array) && is_array($cart_category_id_array) && $cart_category_id_count != 0) {
                $cart_category_id_array = array_unique($cart_category_id_array);
            }

            $category_array_intersect = array();
            $category_array_intersect = array_intersect($category_base_array, $cart_category_id_array);

            $category_array_intersect_count = count($category_array_intersect);

            if (isset($category_array_intersect) && !empty($category_array_intersect) && $category_array_intersect_count >= 1) {
                $has_ship_based_on_category = 'yes';
                $is_passed['has_ship_based_on_category'] = 'yes';
            } else {
                $has_ship_based_on_category = 'no';
                $is_passed['has_ship_based_on_category'] = 'no';
            }
        }
        if (isset($is_passed) && !empty($is_passed) && is_array($is_passed)) {
            foreach ($is_passed as $passed_key => $yes_passed) {

                if ($yes_passed != 'yes') {
                    return false;
                }
            }
            return true;
        }

        return apply_filters('woocommerce_shipping_' . $this->id . '_is_available', $is_available, $package);
    }

    /**
     * calculate_shipping function.
     *
     * @param array $package (default: array())
     */
    public function calculate_shipping($package = array()) {

        $_tax = new WC_Tax();
        $taxes = array();
        $shipping_cost = 0;

        $rate = array(
            'id' => $this->id,
            'label' => $this->title,
            'cost' => 0,
        );

        // Calculate the costs
        $has_costs = false; // True when a cost is set. False if all costs are blank strings.
        $cost = $this->get_option('cost');

        if ($cost !== '') {
            $has_costs = true;
            $rate['cost'] = $this->evaluate_cost($cost, array(
                'qty' => $this->get_package_item_qty($package),
                'cost' => $package['contents_cost']
            ));
        }


        // Add shipping class costs
        $found_shipping_classes = $this->find_shipping_classes($package);
        $highest_class_cost = 0;

        foreach ($found_shipping_classes as $shipping_class => $products) {
            // Also handles BW compatibility when slugs were used instead of ids
            $shipping_class_term = get_term_by('slug', $shipping_class, 'product_shipping_class');
            $class_cost_string = $shipping_class_term && $shipping_class_term->term_id ? $this->get_option('class_cost_' . $shipping_class_term->term_id, $this->get_option('class_cost_' . $shipping_class, '')) : $this->get_option('no_class_cost', '');

            if ($class_cost_string === '') {
                continue;
            }

            $has_costs = true;
            $class_cost = $this->evaluate_cost($class_cost_string, array(
                'qty' => array_sum(wp_list_pluck($products, 'quantity')),
                'cost' => array_sum(wp_list_pluck($products, 'line_total'))
            ));

            if ($this->type === 'class') {
                $rate['cost'] += $class_cost;
            } else {
                $highest_class_cost = $class_cost > $highest_class_cost ? $class_cost : $highest_class_cost;
            }
        }

        if ($this->type === 'order' && $highest_class_cost) {
            $rate['cost'] += $highest_class_cost;
        }

        if (isset($this->shipping_description) && !empty($this->shipping_description)) {
            $rate['method_description'] = $this->shipping_description;
        }

        // Add the rate
        if ($has_costs) {
            $this->add_rate($rate);
        }

        /**
         * Developers can add additional flat rates based on this one via this action since @version 2.4.
         *
         * Previously there were (overly complex) options to add additional rates however this was not user.
         * friendly and goes against what Flat Rate Shipping was originally intended for.
         *
         * This example shows how you can add an extra rate based on this flat rate via custom function:
         *
         * 		add_action( 'woocommerce_flat_rate_shipping_add_rate', 'add_another_custom_flat_rate', 10, 2 );
         *
         * 		function add_another_custom_flat_rate( $method, $rate ) {
         * 			$new_rate          = $rate;
         * 			$new_rate['id']    .= ':' . 'custom_rate_name'; // Append a custom ID.
         * 			$new_rate['label'] = 'Rushed Shipping'; // Rename to 'Rushed Shipping'.
         * 			$new_rate['cost']  += 2; // Add $2 to the cost.
         *
         * 			// Add it to WC.
         * 			$method->add_rate( $new_rate );
         * 		}.
         */
        do_action('woocommerce_' . $this->id . '_shipping_add_rate', $this, $rate, $package);
    }

    /**
     * Get items in package.
     * @param  array $package
     * @return int
     */
    public function get_package_item_qty($package) {
        $total_quantity = 0;
        foreach ($package['contents'] as $item_id => $values) {
            if ($values['quantity'] > 0 && $values['data']->needs_shipping()) {
                $total_quantity += $values['quantity'];
            }
        }
        return $total_quantity;
    }

    /**
     * Finds and returns shipping classes and the products with said class.
     * @param mixed $package
     * @return array
     */
    public function find_shipping_classes($package) {
        $found_shipping_classes = array();

        foreach ($package['contents'] as $item_id => $values) {
            if ($values['data']->needs_shipping()) {
                $found_class = $values['data']->get_shipping_class();

                if (!isset($found_shipping_classes[$found_class])) {
                    $found_shipping_classes[$found_class] = array();
                }

                $found_shipping_classes[$found_class][$item_id] = $values;
            }
        }

        return $found_shipping_classes;
    }

    private function refresh() {
        ?>
        <div class="js"> 
            <div id="preloader"></div>
            <script type="text/javascript">
                jQuery(document).ready(function($) {
                    $(window).load(function() {
                        $('#preloader').fadeOut('slow', function() {
                            $(this).remove();
                        });
                    });
                });
            </script>
        </div>
        <?php
        echo '<script>location.href = ', json_encode(LiteExtraShippingMethodUrl::build_url()), ';</script>';
        die();
    }

    public function admin_options() {

        $is_extra_method_screen = !empty($_GET['extra_method']) ? $_GET['extra_method'] : 'no';

        $manager = Lite_Extra_Shipping_Method::instance(true);
        $profiles = $manager->profiles();
        $profile = $manager->profile();
        $selection_priority = get_option('woocommerce_shipping_method_selection_priority', array());

        $profile_blank_array = get_object_vars($profiles[0]);
        $first_shiiping_title = $profile_blank_array['settings']['title'];

        if (!isset($profile)) {
//            $profile = new self();
//            $profile->_extra_stub = true;
//            $profiles[] = $profile;
        }



        if (!empty($_GET['delete'])) {
            if (isset($profile)) {
                delete_option($profile->get_wp_option_name());
            }
            $this->refresh();
        }
        $plugin_name = "Advanced Flat Rate Shipping Method";
        $plugin_version = "2.4";
        ?> 
        <!-- Dots store extra shipping method start here !-->

        <html>
            <head>
                <meta charset="UTF-8" />
                <meta name="viewport" content="width=device-width, user-scalable=no, initial-scale=1, maximum-scale=1">
                <title>header-1</title>
                <title>flate-rate</title>
                <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.6.3/css/font-awesome.min.css">
                <link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i" rel="stylesheet">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/webkit.css'); ?>">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/style.css'); ?>">
                <link rel="stylesheet" type="text/css" href="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/css/media.css'); ?>">
            </head>

            <body>
                <div id="main">
                    <div class="all-pad">
                        <header>
                            <div class="logo-main">
                                <img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/advance_flat_rate_free.png'); ?>">
                            </div>
                            <div class="header-right">
                                <div class="logo-detail">
                                    <strong><?php echo $plugin_name; ?> </strong>
                                    <span>Free Version <?php echo "v" . $plugin_version; ?></span>

                                </div>
                                <div class="button-dots">
                                    <span class="support_dotstore_image"><a  href="https://store.multidots.com/go/Flatrate-NEWUI-header-UPGRADETO-PRO" target="_blank"><img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/upgrade_new.png'); ?>"> </a></span>
                                    <span class="support_dotstore_image"><a  target = "_blank" href="https://store.multidots.com/dotstore-support-panel/" > <img   src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/support_new.png'); ?>"></a></span>
                                </div>
                            </div>
                        </header>
                        <?php
                        $lite_flate_rate_methode = '';
                        $add_new_lite_flate_rate_methode = '';
                        $premium_tab_dotstore_extra_flate_rate = '';
                        $wc_lite_extra_shipping_get_started_method = '';
                        $wc_lite_extra_shipping_dotstore_contact_support_method = '';
                        $dotstore_introduction_extra_flate_rate_shipping = '';
                        $dotstore_setting_menu_enable = '';
                        $dotpremium_setting_menu_enable = '';

                        if ((!empty($_GET['extra_method']) && $_GET['extra_method'] != '' && !empty($_GET['section']) && $_GET['section'] == 'wc_lite_extra_shipping_method')) {
                            $add_new_lite_flate_rate_methode = "active";
                        }
                        if (( empty($_GET['extra_method']) && !empty($_GET['section']) && $_GET['section'] == 'wc_lite_extra_shipping_method')) {
                            $lite_flate_rate_methode = "active";
                        }

                        if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_premium_method') {
                            $premium_tab_dotstore_extra_flate_rate = "active";
                        }
                        if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_get_started_method') {
                            $wc_lite_extra_shipping_get_started_method = "active";
                        }
                        if (!empty($_GET['tab']) && $_GET['tab'] == 'wc_lite_extra_shipping_dotstore_contact_support_method') {
                            $wc_lite_extra_shipping_dotstore_contact_support_method = "active";
                        }
                        if (!empty($_GET['tab']) && $_GET['tab'] == 'dotstore_introduction_extra_flate_rate_shipping') {
                            $dotstore_introduction_extra_flate_rate_shipping = "active";
                        }
                        if (!empty($_GET['section']) && $_GET['section'] === 'wc_Lite_Extra_Shipping_Method' && empty($_GET['extra_method'])) {
                            $lite_flate_rate_methode = 'active';
                        }
                        $site_url = "admin.php?page=wc_extra_flate_rate_plugin&tab=";
                        ?>
                        <div class="menu-main">
                            <nav>
                                <ul>
                                    <li>
                                        <a class="dotstore_plugin <?php echo $lite_flate_rate_methode; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_method'; ?>">Manage Shipping Methods </a>
                                    </li>
                                    <li>
                                        <a class="dotstore_plugin <?php echo $add_new_lite_flate_rate_methode; ?>" href="<?php echo esc_html(liteExtraShippingMethodUrl::create()) ?>"> Add New Shipping Method </a>
                                    </li>
                                    <li>
                                        <a class="dotstore_plugin <?php echo $premium_tab_dotstore_extra_flate_rate; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_premium_method'; ?>">Premium Version</a>
                                    </li>
                                    <li>
                                        <a class="dotstore_plugin <?php echo $wc_lite_extra_shipping_get_started_method; ?>"  href="<?php echo $site_url . 'wc_lite_extra_shipping_get_started_method'; ?>">About Plugin</a>
                                        <ul class="sub-menu">
                                            <li><a  class="dotstore_plugin <?php echo $wc_lite_extra_shipping_get_started_method; ?>" href="<?php echo $site_url . 'wc_lite_extra_shipping_get_started_method'; ?>">Getting Started</a></li>
                                            <li><a class="dotstore_plugin <?php echo $dotstore_introduction_extra_flate_rate_shipping; ?>" href="<?php echo $site_url . 'dotstore_introduction_extra_flate_rate_shipping'; ?>">Introduction</a></li>
                                            <li><a  target="_blank" href="https://store.multidots.com/suggest-a-feature/">Suggest A Feature</a></li>	
                                            <!--<li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Plugin Tour</a></li>
                                            <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Change Log</a></li>
                                            <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Documention</a></li>
                                            <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Upgrade To Premium</a></li>
                                            <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Suggested Feature</a></li>
                                            <li><a href="<?php //echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=dots-about-plugin-settings');                     ?>">Rate This Plugin</a></li>-->
                                        </ul>

                                    </li>

                                    <li>
                                        <a class="dotstore_plugin <?php echo $wc_lite_extra_shipping_dotstore_contact_support_method; ?>"  href="#">Dotstore</a>
                                        <ul class="sub-menu">
                                            <li><a target="_blank" href="https://store.multidots.com/go/Flatrate-newui-woocommerce-Plugins">WooCommerce Plugins</a></li>
                                            <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-Wordpress-Plugins">Wordpress Plugins</a></li><br>
                                            <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-Wordpress-Plugins">Free Plugins</a></li>
                                            <li><a target="_blank" href="https://store.multidots.com/go/flatrate-newui-theme">Free Themes</a></li>
                                            <li><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Contact Support</a></li>
                                        </ul>
                                    </li>

                                </ul>

                                </li>
                                </ul>
                            </nav>
                        </div>
                        <?php
                        $get_md_woocommerce_shipping_method_format = get_option('md_woocommerce_shipping_method_format', true);
                        if (isset($get_md_woocommerce_shipping_method_format) && !empty($get_md_woocommerce_shipping_method_format)) {
                            $chk = $get_md_woocommerce_shipping_method_format;
                        }
                        ?>  

                        <div class="flat-table res-cl  extra_flate_rate_shipping">

                            <?php
                            if (isset($_POST['save'])) {
                                $extramethod = isset($_GET['extra_method']) ? $_GET['extra_method'] : '';
                                if (!empty($extramethod)) {
                                    $admin_redirct_url = site_url() . '/wp-admin/admin.php?page=wc-settings&tab=shipping&section=wc_Lite_Extra_Shipping_Method';
                                    ?>
                                    <div id="message" class="updated inline"><p><strong>Your settings have been saved.</strong></p></div>
                                    <script type="text/javascript">
                                        var redirect_location = '<?php echo $admin_redirct_url; ?>';
                                        window.location.href = redirect_location;
                                    </script>
                                    <?php
                                }
                            }
                            ?>
                            <?php if ($is_extra_method_screen == 'no' && $is_extra_method_screen === 'no') { ?>   
                                <style type="text/css">.dotstore_plugin_supports_feature {margin-top: -19px !important;}</style>
                                <table class="form-table wc_shipping widefat wp-list-table table-outer" id="extra_shipping_method_listing" cellspacing="0">
                                    <thead>
                                        <tr>
                                            <th class="name" width="40%"><?php _e('Shipping Method Name', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></th>
                                            <th class="cost" width="20%"><?php _e('Amount', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></th>
                                            <th class="status" width="20%"><?php _e('Status', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></th>
                                            <th class="remove" width="20%"><?php _e('Action', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?></th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php
                                        if (!empty($first_shiiping_title) && $first_shiiping_title != '') {
                                            foreach ($profiles as $key => $method) :
                                                ?>
                                                <tr>
                                                    <td class="name" width="40%">
                                                        <?php if (isset($method->id) && !empty($method->id)) : ?><a href="<?php echo esc_url(admin_url('admin.php?extra_method=' . esc_attr($method->id) . '&page=wc-settings&tab=shipping&section=wc_lite_extra_shipping_method')); ?>"><?php endif; ?>
                                                            <?php echo esc_html($method->get_title()); ?>
                                                            <?php
                                                            if ($method->id == 'extra_shipping') {
                                                                echo '<img class="help_tip" data-tip="It is Default shipping method (With this method, you can apply forcefully/compulsory shipping method." src="' . esc_url(WC()->plugin_url()) . '/assets/images/help.png" height="16" width="16" />';
                                                            }
                                                            ?>


                                                            <?php if (isset($method->shipping_description)) : ?></a>
                                                            <?php $method_description = empty($method->shipping_description) ? $method->title : $method->shipping_description; ?>
                                                        <?php endif; ?>
                                                    </td>

                                                    <td class="cost" width="20%" >
                                                        <?php echo get_woocommerce_currency_symbol() . esc_attr($method->cost); ?>
                                                    </td>
                                                    <td width="20%">
                                                        <?php
                                                        $get_opt = get_option('extra_' . $method->id . '_settings');
                                                        $unget_opt = maybe_unserialize($get_opt);
                                                        if ('yes' === $unget_opt['enabled']) :
                                                            ?>
                                                            <?php _e('Enabled', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?> 
                                                        <?php else : ?>
                                                            <?php _e('Disabled', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?> 
                                                        <?php endif;
                                                        ?>
                                                    </td>

                                                    <td class="remove_extra_shipping_method" width="20%">
                                                        <a class="wc-email-settings-table-actions button button-primary" href="<?php echo esc_url(admin_url('admin.php?extra_method=' . esc_attr($method->id) . '&page=wc-settings&tab=shipping&section=wc_lite_extra_shipping_method')); ?>" > <?php _e('Edit', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG); ?> </a>
                                                        <?php if ($method->id != 'extra_shipping') { ?>
                                                            <a class="button button-primary" href="<?php echo esc_html(LiteExtraShippingMethodUrl::delete($method)) ?>"
                                                               onclick="return confirm('<?php esc_html_e('Are you sure you want to delete this shipping method?', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) ?>');">
                                                                   <?php esc_html_e('Delete') ?>
                                                            </a>
                                                        <?php } ?>
                                                    </td>

                                                </tr>

                                                <?php
                                            endforeach;
                                        } else {
                                            ?>
                                            <tr>
                                                <td width="40%" colspan="4">
                                                    <?php echo 'No Shipping Method Available'; ?>
                                                </td>
                                            </tr>
                                            <?php
                                        }
                                        ?>
                                    </tbody>
                                </table>
                                </br>

                                <?php if (!isset($_GET['extra_method']) && empty($_GET['extra_method'])) { ?>
                                    <div class="md_div_display_shipping">
                                        <table class="form-table table-outer extra_shipping_method_listing setting_field">
                                            <th>Shipping Method Settings </th>
                                        </table>
                                    </div>
                                    <div class="md_div_display_shipping">
                                        <table class="form-table table-outer extra_shipping_method_listing">
                                            <tr valign="top" class="">
                                                <th scope="row" class="titledesc">
                                                    <label for="woocommerce_shipping_method_format"><?php echo __('Shipping Display Mode', 'woo-extra-flat-rate'); ?></label>
                                                </th>
                                                <td class="forminp forminp-radio">
                                                    <fieldset>
                                                        <ul>
                                                            <li>
                                                                <label><input name="md_woocommerce_shipping_method_format" value="radio"  type="radio" style="" class="" <?php echo ($chk == 'radio' ? 'checked' : ''); ?>> <?php echo __('Display shipping methods with "radio" buttons', 'woo-extra-flat-rate'); ?></label>
                                                            </li>
                                                            <li>
                                                                <label><input name="md_woocommerce_shipping_method_format" value="select"  type="radio" style="" class="" <?php echo ($chk == 'select' ? 'checked' : ''); ?>><?php echo __('Display shipping methods in a dropdown', 'woo-extra-flat-rate'); ?></label>
                                                            </li>
                                                        </ul>
                                                    </fieldset>
                                                </td>
                                            </tr>
                                            <tr>	
                                                <td colspan="2">
                                                    <span class="button-primary" id="btn_shipping" name="btn_shipping">Save Display Mode</span>
                                                </td>
                                            </tr>
                                        </table>
                                    </div>	
                                <?php } ?>




                            </div><!--  wc-col-container-->
                            <?php
                        }


                        if ($is_extra_method_screen != 'no') {
                            ?>
                            <div id="extra-shipping-methods-details">

                                <?php $profile->generate_settings_html(); ?>
                                <p class="submit extra-flat-rate-save-change" id="extra-flat-rate-custom-save-button">
                                    <?php if (!isset($GLOBALS['hide_save_button'])) : ?>
                                        <input name="save" class="button-primary" type="submit" value="<?php esc_attr_e('Save changes', 'woocommerce'); ?>" />
                                    <?php endif; ?>
                                    <input type="hidden" name="subtab" id="last_tab" />
                                    <?php wp_nonce_field('woocommerce-settings'); ?>
                                </p>




                            </div>

                            <?php
                        }
                        ?>


                        <!--  end !-->
                        <!--</table>!-->

                    </div>	
                    <!-- end here !-->	
                    <?php $site_url = "admin.php?page=wc_extra_flate_rate_plugin&tab="; ?>
                    <div class="dotstore_plugin_supports_feature">
                        <div class="right-sec">
                            <div class="woo-top">
                                <span>discover features</span>
                            </div>
                            <div class="discover">
                                <div class="video">
                                    <iframe width="100%" height="232" src="https://www.youtube.com/embed/HqlBb7OoyFo" frameborder="0" allowfullscreen></iframe>
                                </div>

                                <div class="video-detail">
                                    <ul>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span >Location Based Shipping Rules </span><li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span>Product Based Shipping Rules</span> <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span>User Based Shipping Rules</span> </li><li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><span >Coupon, Quantity Based Shipping Rules</span></li>
                                    </ul>
                                </div>
                                <div class="view-button">
                                    <a  class="view_button_dotstore" target="_blank" href="<?php echo $site_url . 'wc_lite_extra_shipping_premium_method'; ?>" >view details</a>
                                    <a  class="live_button_dotstore" target="_blank" href="http://extraflatratedemo.projectsmd.in/">live demo</a>
                                </div>
                            </div>
                            <div class="dotstore-bloguju">
                                <img width="100%" src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/Discount.png'); ?>">
                            </div>

                            <div class="upgrader_pro_version_button">
                                <a href="https://store.multidots.com/go/Flatrate-NEWUI-UPGRADETO-PRO--sidebar" target="_blank"><img  src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/upgrade_new.png'); ?>"> </a>
                            </div>

                            <div class="dotstore-important-link">
                                <h2><span class="dotstore-important-link-title">Important link</span></h2>
                                <div class="video-detail important-link">
                                    <ul>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/docs/plugin/advanced-flat-rate-shipping-method-for-woocommerce/">Plugin documentation</a></li> 
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Support platform</a></li>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a target="_blank" href="https://store.multidots.com/suggest-a-feature/">Suggest A Feature</li>
                                        <li><img src="<?php echo site_url('wp-content/plugins/woo-extra-flat-rate//admin/images/right_click.png'); ?>"><a  target="_blank" href="https://store.multidots.com/advanced-flat-rate-shipping-method-for-woocommerce/">Changelog</li>
                                    </ul>
                                </div>
                            </div>

                        </div>

                    </div>

                    <div class="footer">
                    </div>
                </div>
            </body>			
            <html>
                <?php
                exit;
            }

            public function generate_settings_html($form_fields = array(), $echo = true) {
                $html_group_one = '';
                $html_group_two = '';
                $html_group_three = '';
                $html_group_location = '';
                $fields_group_one = array();
                $fields_group_two = array();
                $fields_group_three = array();

                $fields_group_location = '';
                $fields_group_location = array();

                $html_group_product = '';
                $fields_group_product = '';
                $fields_group_product = array();


                $html_group_user = '';
                $fields_group_user = '';
                $fields_group_user = array();

                if (empty($form_fields)) {
                    $form_fields = $this->get_form_fields();
                }

                foreach ($form_fields as $k => $v) {

                    if ($k == 'enabled' || $k == 'title' || $k == 'shipping_description' || $k == 'cost' || $k == 'user_id_extra_flat') {
                        $fields_group_one[] = $k;
                    }

                    $extra_method = $_GET['extra_method'] == 'extra_shipping' ? $_GET['extra_method'] : '';
                    if (isset($extra_method) && !empty($extra_method) && $extra_method == 'extra_shipping') {

                        if ($k == 'master_class' || $k == 'countries' || $k == 'coupon' || $k == 'min_amount' || $k == 'max_amount' || $k == 'min_extra_quantity' || $k == 'max_quantity' || $k == 'min_weight' || $k == 'max_weight' || $k == 'tax_status') {
                            $fields_group_two[] = $k;
                        }

                        if ($k == 'availability' || $k == 'country_zone' || $k == 'zone_base') {
                            $fields_group_location[] = $k;
                        }

                        if ($k == 'product_base' || $k == 'category_base' || $k == 'tag_base' || $k == 'sku_base') {
                            $fields_group_product[] = $k;
                        }

                        if ($k == 'user_base' || $k == 'user_role_base') {
                            $fields_group_user[] = $k;
                        }
                    } else {
                        if ($k == 'countries' || $k == 'coupon' || $k == 'min_amount' || $k == 'max_amount' || $k == 'min_extra_quantity' || $k == 'max_quantity' || $k == 'min_weight' || $k == 'max_weight' || $k == 'tax_status') {
                            $fields_group_two[] = $k;
                        }

                        if ($k == 'availability' || $k == 'country_zone' || $k == 'zone_base') {
                            $fields_group_location[] = $k;
                        }

                        if ($k == 'product_base' || $k == 'category_base' || $k == 'tag_base' || $k == 'sku_base') {
                            $fields_group_product[] = $k;
                        }

                        if ($k == 'user_base' || $k == 'user_role_base') {
                            $fields_group_user[] = $k;
                        }
                    }

                    if (strpos($k, 'class_cost_') !== false || $k == 'type' || $k == 'class_costs') {
                        $fields_group_three[] = $k;
                    }

                    if (!isset($v['type']) || ( $v['type'] == '' )) {
                        $v['type'] = 'text'; // Default to "text" field type.
                    }
                    if (in_array($k, $fields_group_one)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html_own')) {
                            $html_group_one .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_one .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }


                    if (in_array($k, $fields_group_location)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html_own')) {
                            $html_group_location .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_location .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }


                    if (in_array($k, $fields_group_product)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html')) {
                            $html_group_product .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_product .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }


                    if (in_array($k, $fields_group_user)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html_own')) {
                            $html_group_user .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_user .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }



                    if (in_array($k, $fields_group_two)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html_own')) {
                            $html_group_two .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_two .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }

                    if (in_array($k, $fields_group_three)) {
                        if (method_exists($this, 'generate_' . $v['type'] . '_html_own')) {
                            $html_group_three .= $this->{'generate_' . $v['type'] . '_html_own'}($k, $v);
                        } else {
                            $html_group_three .= $this->{'generate_text_html_own'}($k, $v);
                        }
                    }
                }
                //$tooltip_icone = site_url('wp-content/plugins/woo-extra-flat-rate/admin/images/icon-help-circled.png');
                ?>
                <style type="text/css">p.description {display: none;}span.advance_extra_flate_rate_disctiption_tab{ background: url(<?php echo $tooltip_icone; ?>)}span.advance_extra_flate_rate_disctiption_tab {float: right;}
                    .woocommerce table.form-table .select2-container {display: inline-block !important;max-width: 350px;vertical-align: top;margin-bottom: 3px;float: left;}
                    span.advance_extra_flate_rate_disctiption_tab {float: none !important;}
                </style>
                <?php
                $htmlall = '';
                $htmlall = '<style type=text/css>span.woocommerce-help-tip {margin: 0px -15px 0 0 !important;}div#tiptip_content {font-size: 10px;line-height: 15px;}</style>';
                $htmlall .='<h2>' . __('Shipping Method: Basic Configuration', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) . '</h2>';
                $htmlall .='<table class="form-table table-outer" id="extra_shipping_method_settings" cellspacing="0">';
                $htmlall .= $html_group_one;
                $htmlall .='</table>';

                $htmlall .='<h2>' . __('Product Based Shipping Method Rule', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) . ' </h2>';
                $htmlall .='<table class="form-table table-outer" id="extra_shipping_method_settings" cellspacing="0">';
                $htmlall .= $html_group_product;
                $htmlall .='</table>';


                $htmlall .='<h2>' . __('Country Based Shipping Method Rule', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) . ' </h2>';
                $htmlall .='<table class="form-table table-outer" id="extra_shipping_method_settings" cellspacing="0">';
                $htmlall .= $html_group_two;
                $htmlall .='</table>';

                if (!empty($html_group_three) && $html_group_three != '') {
                    $htmlall .='<h2>' . __('Shipping Class Base Shipping Method Rule', AD_LITE_FLAT_RATE_SHIPPING_METHOD_PLUGIN_SLUG) . ' </h2>';
                    $htmlall .='<table class="form-table table-outer" id="extra_shipping_method_settings" cellspacing="0">';
                    $htmlall .= $html_group_three;
                    $htmlall .='</table>';
                }


                echo $htmlall;
            }

            /**
             * Generate Text Input HTML.
             *
             * @param  mixed $key
             * @param  mixed $data
             * @since  1.0.0
             * @return string
             */
            public function generate_text_html_own($key, $data) {
                $field_key = $this->get_field_key($key);
                $defaults = array(
                    'title' => '',
                    'disabled' => false,
                    'class' => '',
                    'css' => '',
                    'placeholder' => '',
                    'type' => 'text',
                    'desc_tip' => false,
                    'description' => '',
                    'custom_attributes' => array(),
                );

                $data = wp_parse_args($data, $defaults);

                ob_start();
                ?>
                <tr valign="top">
                    <th scope="row" class="titledesc">
                        <label for="<?php echo esc_attr($field_key); ?>"><?php echo wp_kses_post($data['title']); ?></label>
                        <?php //echo $this->get_tooltip_html( $data );    ?>
                    </th>
                    <td class="forminp">
                        <fieldset>
                            <legend class="screen-reader-text"><span><?php echo wp_kses_post($data['title']); ?></span></legend>
                            <input class="input-text regular-input <?php echo esc_attr($data['class']); ?>" type="<?php echo esc_attr($data['type']); ?>" name="<?php echo esc_attr($field_key); ?>" id="<?php echo esc_attr($field_key); ?>" style="<?php echo esc_attr($data['css']); ?>" value="<?php echo esc_attr($this->get_option($key)); ?>" placeholder="<?php echo esc_attr($data['placeholder']); ?>" <?php disabled($data['disabled'], true); ?> <?php echo $this->get_custom_attribute_html($data); ?> />

                            <span class="advance_extra_flate_rate_disctiption_tab" style="background-size: 16px; display: inline-block;width: 16px !important;height: 17px !important;margin-left: 10px;background-size: 16px; background-image: url('<?php echo site_url('wp-content/plugins/woocommerce/assets/images/help.png'); ?>'); display: inline-block; width: 20px; height: 21px; margin-left: 10px;"></span>
                            <?php echo $this->get_description_html($data); ?>
                            <?php //echo $this->get_tooltip_html( $data );   ?>
                        </fieldset>
                    </td>
                </tr>
                <?php
                return ob_get_clean();
            }

            /**
             * Generate Checkbox HTML.
             *
             * @param  mixed $key
             * @param  mixed $data
             * @since  1.0.0
             * @return string
             */
            public function generate_checkbox_html_own($key, $data) {
                $field_key = $this->get_field_key($key);
                $defaults = array(
                    'title' => '',
                    'label' => '',
                    'disabled' => false,
                    'class' => '',
                    'css' => '',
                    'type' => 'text',
                    'desc_tip' => false,
                    'description' => '',
                    'custom_attributes' => array(),
                );

                $data = wp_parse_args($data, $defaults);

                if (!$data['label']) {
                    $data['label'] = $data['title'];
                }

                ob_start();
                ?>
                <tr valign="top">
                    <th scope="row" class="titledesc">
                        <label for="<?php echo esc_attr($field_key); ?>"><?php echo wp_kses_post($data['title']); ?></label>
                        <?php //echo $this->get_tooltip_html( $data );    ?>
                    </th>
                    <td class="forminp">
                        <fieldset>

                            <legend class="screen-reader-text"><span><?php echo wp_kses_post($data['title']); ?></span></legend>

                            <label for="<?php echo esc_attr($field_key); ?>">
                                <input <?php disabled($data['disabled'], true); ?> class="<?php echo esc_attr($data['class']); ?>" type="checkbox" name="<?php echo esc_attr($field_key); ?>" id="<?php echo esc_attr($field_key); ?>" style="<?php echo esc_attr($data['css']); ?>" value="1" <?php checked($this->get_option($key), 'yes'); ?> <?php echo $this->get_custom_attribute_html($data); ?> /> 
                                <?php
                                if ($key === 'enabled') {
                                    //echo wp_kses_post( $data['label'] ); 
                                } else {
                                    echo wp_kses_post($data['label']);
                                }
                                ?>

                            </label>
                            <?php if ($key === 'enabled') { ?> 
                                <span class="advance_extra_flate_rate_disctiption_tab" style=" background-size: 16px; display: inline-block;width: 16px !important;height: 17px !important;margin-left: 10px; background-image: url('<?php echo site_url('wp-content/plugins/woocommerce/assets/images/help.png'); ?>');"></span>
                                <?php //echo $this->get_tooltip_html( $data );   ?>
                            <?php } ?>
                            <?php echo $this->get_description_html($data); ?>

                        </fieldset>
                    </td>
                </tr>
                <?php
                return ob_get_clean();
            }

            /**
             * Generate Multiselect HTML.
             *
             * @param  mixed $key
             * @param  mixed $data
             * @since  1.0.0
             * @return string
             */
            public function generate_multiselect_html_own($key, $data) {
                $field_key = $this->get_field_key($key);
                $defaults = array(
                    'title' => '',
                    'disabled' => false,
                    'class' => '',
                    'css' => '',
                    'placeholder' => '',
                    'type' => 'text',
                    'desc_tip' => false,
                    'description' => '',
                    'custom_attributes' => array(),
                    'select_buttons' => false,
                    'options' => array(),
                );

                $data = wp_parse_args($data, $defaults);
                $value = (array) $this->get_option($key, array());
                ob_start();
                ?>
                <tr valign="top">
                    <th scope="row" class="titledesc">
                        <label for="<?php echo esc_attr($field_key); ?>"><?php echo wp_kses_post($data['title']); ?></label>
                    </th>

                    <td class="forminp">
                        <fieldset>
                            <legend class="screen-reader-text"><span><?php echo wp_kses_post($data['title']); ?></span></legend>

                            <select multiple="multiple" class="multiselect <?php echo esc_attr($data['class']); ?>" name="<?php echo esc_attr($field_key); ?>[]" id="<?php echo esc_attr($field_key); ?>" style="<?php echo esc_attr($data['css']); ?>" <?php disabled($data['disabled'], true); ?> <?php echo $this->get_custom_attribute_html($data); ?>>
                                <?php foreach ((array) $data['options'] as $option_key => $option_value) : ?>
                                    <option value="<?php echo esc_attr($option_key); ?>" <?php selected(in_array($option_key, $value), true); ?>><?php echo esc_attr($option_value); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <!--<span class="advance_extra_flate_rate_disctiption_tab" style="display: inline-block;width: 16px !important;height: 17px !important;margin-left: 10px;  background-size: 16px; background-image: url('<?php echo site_url('wp-content/plugins/woocommerce/assets/images/help.png'); ?>'); "></span>-->

                            <?php //echo $this->get_tooltip_html( $data );    ?>
                            <?php if ($data['select_buttons']) : ?>
                                <br/><a class="select_all button" href="#"><?php _e('Select all', 'woocommerce'); ?></a> <a class="select_none button" href="#"><?php _e('Select none', 'woocommerce'); ?></a>
                            <?php endif; ?>
                            <style type="text/css">p.description {margin-top: 15px !important;}</style>
                            <span class="advance_extra_flate_rate_disctiption_tab" style="display: inline-block;width: 16px !important;height: 17px !important;margin-left: 10px;  background-size: 16px; background-image: url('<?php echo site_url('wp-content/plugins/woocommerce/assets/images/help.png'); ?>'); "></span>
                            <?php echo $this->get_description_html($data); ?>
                        </fieldset>

                    </td>
                </tr>
                <?php
                return ob_get_clean();
            }

            /**
             * Generate Select HTML.
             *
             * @param  mixed $key
             * @param  mixed $data
             * @since  1.0.0
             * @return string
             */
            public function generate_select_html_own($key, $data) {
                $field_key = $this->get_field_key($key);
                $defaults = array(
                    'title' => '',
                    'disabled' => false,
                    'class' => '',
                    'css' => '',
                    'placeholder' => '',
                    'type' => 'text',
                    'desc_tip' => false,
                    'description' => '',
                    'custom_attributes' => array(),
                    'options' => array(),
                );

                $data = wp_parse_args($data, $defaults);

                ob_start();
                ?>
                <tr valign="top">
                    <th scope="row" class="titledesc">
                        <label for="<?php echo esc_attr($field_key); ?>"><?php echo wp_kses_post($data['title']); ?></label>
                        <?php //echo $this->get_tooltip_html( $data );    ?>
                    </th>
                    <td class="forminp">
                        <fieldset>
                            <legend class="screen-reader-text"><span><?php echo wp_kses_post($data['title']); ?></span></legend>
                            <select style="width:100%"class="select <?php echo esc_attr($data['class']); ?>" name="<?php echo esc_attr($field_key); ?>" id="<?php echo esc_attr($field_key); ?>" style="<?php echo esc_attr($data['css']); ?>" <?php disabled($data['disabled'], true); ?> <?php echo $this->get_custom_attribute_html($data); ?>>
                                <?php foreach ((array) $data['options'] as $option_key => $option_value) : ?>
                                    <option value="<?php echo esc_attr($option_key); ?>" <?php selected($option_key, esc_attr($this->get_option($key))); ?>><?php echo esc_attr($option_value); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <span class="advance_extra_flate_rate_disctiption_tab" style=" background-size: 16px; display: inline-block;width: 16px !important;height: 17px !important;margin-left: 10px; background-image: url('<?php echo site_url('wp-content/plugins/woocommerce/assets/images/help.png'); ?>');"></span>
                            <?php //echo $this->get_tooltip_html( $data );   ?>
                            <?php echo $this->get_description_html($data); ?>
                        </fieldset>
                    </td>
                </tr>
                <?php
                return ob_get_clean();
            }

            /**
             * Adds extra calculated flat rates.
             *
             * @deprecated 2.4.0
             *
             * Additonal rates defined like this:
             * 	Option Name | Additional Cost [+- Percents%] | Per Cost Type (order, class, or item).
             */
            public function calculate_extra_shipping($method, $rate, $package) {
                if ($this->options) {
                    $options = array_filter((array) explode("\n", $this->options));

                    foreach ($options as $option) {
                        $this_option = array_map('trim', explode(WC_DELIMITER, $option));
                        if (sizeof($this_option) !== 3) {
                            continue;
                        }
                        $extra_rate = $rate;
                        $extra_rate['id'] = $this->id . ':' . urldecode(sanitize_title($this_option[0]));
                        $extra_rate['label'] = $this_option[0];
                        $extra_cost = $this->get_extra_cost($this_option[1], $this_option[2], $package);
                        if (is_array($extra_rate['cost'])) {
                            $extra_rate['cost']['order'] = $extra_rate['cost']['order'] + $extra_cost;
                        } else {
                            $extra_rate['cost'] += $extra_cost;
                        }
                        $this->add_rate($extra_rate);
                    }
                }
            }

            /**
             * Calculate the percentage adjustment for each shipping rate.
             *
             * @deprecated 2.4.0
             * @param  float  $cost
             * @param  float  $percent_adjustment
             * @param  string $percent_operator
             * @param  float  $base_price
             * @return float
             */
            public function calc_percentage_adjustment($cost, $percent_adjustment, $percent_operator, $base_price) {
                if ('+' == $percent_operator) {
                    $cost += $percent_adjustment * $base_price;
                } else {
                    $cost -= $percent_adjustment * $base_price;
                }
                return $cost;
            }

            /**
             * Get extra cost.
             *
             * @deprecated 2.4.0
             * @param  string $cost_string
             * @param  string $type
             * @param  array $package
             * @return float
             */
            public function get_extra_cost($cost_string, $type, $package) {
                $cost = $cost_string;
                $cost_percent = false;
                $pattern = '/' . // start regex
                        '(\d+\.?\d*)' . // capture digits, optionally capture a `.` and more digits
                        '\s*' . // match whitespace
                        '(\+|-)' . // capture the operand
                        '\s*' . // match whitespace
                        '(\d+\.?\d*)' . // capture digits, optionally capture a `.` and more digits
                        '\%/';          // match the percent sign & end regex
                if (preg_match($pattern, $cost_string, $this_cost_matches)) {
                    $cost_operator = $this_cost_matches[2];
                    $cost_percent = $this_cost_matches[3] / 100;
                    $cost = $this_cost_matches[1];
                }
                switch ($type) {
                    case 'class' :
                        $cost = $cost * sizeof($this->find_shipping_classes($package));
                        break;
                    case 'item' :
                        $cost = $cost * $this->get_package_item_qty($package);
                        break;
                }
                if ($cost_percent) {
                    switch ($type) {
                        case 'class' :
                            $shipping_classes = $this->find_shipping_classes($package);
                            foreach ($shipping_classes as $shipping_class => $items) {
                                foreach ($items as $item_id => $values) {
                                    $cost = $this->calc_percentage_adjustment($cost, $cost_percent, $cost_operator, $values['line_total']);
                                }
                            }
                            break;
                        case 'item' :
                            foreach ($package['contents'] as $item_id => $values) {
                                if ($values['data']->needs_shipping()) {
                                    $cost = $this->calc_percentage_adjustment($cost, $cost_percent, $cost_operator, $values['line_total']);
                                }
                            }
                            break;
                        case 'order' :
                            $cost = $this->calc_percentage_adjustment($cost, $cost_percent, $cost_operator, $package['contents_cost']);
                            break;
                    }
                }
                return $cost;
            }

            public function process_admin_options() {
                $result = parent::process_admin_options();

                $this->init();

                $clone = Lite_Extra_Shipping_Method::instance()->profile($this->profile_id);
                if (isset($clone) && $clone !== $this) {
                    $clone->init();
                }

                if ($result) {
                    $this->purge_woocommerce_shipping_cache();
                }

                return $result;
            }

            private function purge_woocommerce_shipping_cache() {
                global $wpdb;

                $transients = $wpdb->get_col("
		    SELECT SUBSTR(option_name, LENGTH('_transient_') + 1)
		    FROM `{$wpdb->options}`
		    WHERE option_name LIKE '_transient_wc_ship_%'
		");

                foreach ($transients as $transient) {
                    delete_transient($transient);
                }
            }

            public function __clone() {
                $manager = Lite_Extra_Shipping_Method::instance();

                $this->profile_id = $manager->new_profile_id();
                $this->id = $manager->find_suitable_id($this->profile_id);

                $this->name .= ' (' . _x('copy', 'noun', 'extra_shipping') . ')';
                $this->settings['name'] = $this->name;
            }

        }
        