<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Woo_Extra_Flat_Rate
 * @subpackage Woo_Extra_Flat_Rate/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Woo_Extra_Flat_Rate
 * @subpackage Woo_Extra_Flat_Rate/includes
 * @author     Multidots <wordpress@multidots.com>
 */
class Woo_Extra_Flat_Rate {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Woo_Extra_Flat_Rate_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->plugin_name = 'woo-extra-flat-rate';
		$this->version = '2.1';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Woo_Extra_Flat_Rate_Loader. Orchestrates the hooks of the plugin.
	 * - Woo_Extra_Flat_Rate_i18n. Defines internationalization functionality.
	 * - Woo_Extra_Flat_Rate_Admin. Defines all hooks for the admin area.
	 * - Woo_Extra_Flat_Rate_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woo-extra-flat-rate-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-woo-extra-flat-rate-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-woo-extra-flat-rate-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-woo-extra-flat-rate-public.php';

		$this->loader = new Woo_Extra_Flat_Rate_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Woo_Extra_Flat_Rate_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Woo_Extra_Flat_Rate_i18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {
		
		$plugin_admin = new Woo_Extra_Flat_Rate_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action('admin_init', $plugin_admin, 'extra_flat_rate_admin_init_own');
		$this->loader->add_action('admin_init', $plugin_admin, 'welcome_screen_do_activation_redirect');
		$this->loader->add_action('admin_menu', $plugin_admin, 'welcome_screen_pages');
		$this->loader->add_action('admin_head', $plugin_admin, 'welcome_screen_remove_menus');
		$this->loader->add_action('wp_ajax_my_dismiss_flatrate_notice', $plugin_admin, 'my_dismiss_flatrate_notice');

		$get_notice = get_option( 'woo-extra-flat-rate-notice-dismissed' ) ;
		if( empty($get_notice ) ) {
			$this->loader->add_action('admin_notices', $plugin_admin, 'admin_notices_extra_flat_rate');
		}
		$this->loader->add_action( 'wp_ajax_add_plugin_user_wcef', $plugin_admin, 'wp_add_plugin_userfn_wcef' );
		$this->loader->add_action( 'wp_ajax_hide_subscribe', $plugin_admin, 'hide_subscribe_own' );
					
		$this->loader->add_action('woocommerce_extra_flate_rate_other_plugins', $plugin_admin, 'woocommerce_extra_flate_rate_other_plugins');
        $this->loader->add_action('woocommerce_extra_flate_rate_about', $plugin_admin, 'woocommerce_extra_flate_rate_about');
        $this->loader->add_action('woocommerce_extra_flate_rate_Premium_feature', $plugin_admin, 'woocommerce_extra_flate_rate_Premium_feature');
        $this->loader->add_action('admin_print_footer_scripts', $plugin_admin, 'custom_woo_extra_flate_rate_pointers_footer');
        
        global $woocommerce;
       	$this->loader->add_action('admin_init', $plugin_admin, 'extra_flat_rate_admin_init_own');
       	$this->loader->add_action( 'wp_ajax_displaymode', $plugin_admin,'set_display_modefunction' );
       	
       	if( !empty( $_GET['section'] ) && $_GET['section'] === 'wc_extra_shipping_method' ) { 
       		
       	} else { 
       		$this->loader->add_action('plugins_loaded', $plugin_admin, 'extra_shipping_method_load_1',10);
       	}
       	
       	// custom menu for dotstore
       	if ( empty ( $GLOBALS['admin_page_hooks']['dots_store'] ) ) {
		    $this->loader->add_action('admin_menu',$plugin_admin,'dot_store_menu_extra_flate_rate');
		}
		$this->loader->add_action("admin_menu" , $plugin_admin , "add_new_menu_items_extra_flate_rate_shipping");
		$this->loader->add_action( 'admin_head',$plugin_admin, 'woo_extra_flate_rate_active_menu' );
		$this->loader->add_action( 'admin_menu',$plugin_admin, 'remove_custom_dots_store_from_admin_menu' );
		
		$this->loader->add_action('admin_body_class', $plugin_admin ,'extra_flat_rate_add_body_class',10,1 );
		$this->loader->add_action('woocommerce_get_sections_shipping', $plugin_admin, 'woocommerce_get_sections_shipping_custom_lite', 20, 2); 
		
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Woo_Extra_Flat_Rate_Public( $this->get_plugin_name(), $this->get_version() );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action( 'woocommerce_flat_rate_shipping_add_rate', $plugin_public, 'add_another_custom_flat_rate1',10,2 );
		$this->loader->add_action( 'woocommerce_extra_shipping_shipping_add_rate', $plugin_public, 'add_another_custom_flat_rate1',10,2 );
		$this->loader->add_filter('woocommerce_paypal_args',  $plugin_public,'paypal_bn_code_filter_extra_flate_rate', 99, 1);
		$get_md_woocommerce_shipping_method_format = get_option('md_woocommerce_shipping_method_format',true);
		
		if (isset($get_md_woocommerce_shipping_method_format) && !empty($get_md_woocommerce_shipping_method_format)) {
			$this->loader->add_filter('woocommerce_locate_template',  $plugin_public, 'md_adon_plugin_template', 11, 3 );
		}
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Woo_Extra_Flat_Rate_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
